define(['zepto', 'C', 'view', 'chart'], function($, C, View, Chart) {
    'use strict';

    var Page = View.extend(_.extend({
        tagName: '',
        className: '',
        el: 'body',
        events: {},
        // 实例化后默认初始化该方法
        initialize: function() {
            var self = this;
            //设置标题
            C.Native.setHeader({
                title: C.Constant.TITLE.ASSETS,
                leftCallback: function() {
                    C.Native.back();
                }
            });         
            C.UI.loading();
            C.Native.getYiQianBaoBalance(function (res) {
                C.UI.stopLoading();
                if (C.Flag.SUCCESS == res.flag) {
                    
                    var data = [
                        {
                            value: parseFloat(res.data.mainBalance.replace(/,/g, '')),
                            label: '余额'
                        },
                        {
                            value: parseFloat(res.data.hqBaoBalance.replace(/,/g, '')),
                            label: '活钱宝'
                        }
                    ];
                    data = self.chartDataModify(data);
                    self.render(data);
                } else {                        
                    C.Native.tip(res.msg);
                }
            });
        },

        // 渲染整个view
        render: function(data) {
            var self = this;
            //关于8.2和8.3的ios系统的6plus没有显示圆圈的情况作处理
            if(navigator.userAgent.indexOf("iPhone")>-1 && navigator.userAgent.match(/OS 8_[0-9]* like Mac OS X/i)){
                if(window.devicePixelRatio==3){//6plus
                   window.devicePixelRatio=2;
                }
            }
            var ctx = $("#myChart").get(0).getContext("2d");
            var config = {
                responsive: true,
                segmentShowStroke: false,
                showTooltips: false,
                animationEasing:"linear",
                legendTemplate: "<ul><% for (var i=0; i<segments.length; i++){%><li><span class=\"color\" style=\"background:<%=segments[i].fillColor%>;\"></span><%=segments[i].label%></li><%}%></ul>",
                onAnimationComplete: function() {
                    $('.total-money').show().find('.money').html(data.total);
                }
            };

             if (/Mobile/i.test(navigator.userAgent)) {
                //针对手机，性能做一些降级，看起来就不会那么卡了
                config.animationSteps = Chart.defaults.global.animationSteps / 6;
                config.animationEasing="linear"; 
            }
            var myNewChart = new Chart(ctx).Doughnut(data.list, config);

            //对总额为零的情况对圆圈作处理
            if (data.total == "0.00") {
              var  myNewChart1 = new Chart(ctx).Doughnut(self.gradient(100, '#E0E0E0', '#FAFAFA'), config);
            }
            var legend = myNewChart.generateLegend();
            this.$el.find('.assets').html(legend);
            $('.total-money').show().find('.money').html(data.total);

        },
        chartDataModify: function(data) {
            var colorsConfig = ["#5dc3f5", "#f27661", "#9ecd5c"],
                totalMoney = 0,
                zeroCount = 0;
            for (var i = 0; i < data.length; i++) {
                var colorLength = colorsConfig.length;
                data[i].color = colorsConfig[i % colorLength];
                //修复只有一个值时老浏览器不显示的问题
                if (data[i].value < 0.005) {
                    zeroCount++;
                    data[i].value = 0.001;
                }

                var moneyFormat = C.Utils.formatMoney(data[i].value, 2);
                data[i].label = "<span class=\"num\">" + moneyFormat + "</span>" + data[i].label;
                totalMoney += data[i].value;
            }
            if (zeroCount == data.length) {
                for (var i = 0; i < data.length; i++) {
                    data[i].value = 0;
                }
            }

            totalMoney = C.Utils.formatMoney(totalMoney, 2);
            return {
                total: totalMoney,
                list: data
            };
        },
        //颜色从#xxxxxx 到 rgb
        color2rgb: function(color) {
            var r = parseInt(color.substr(1, 2), 16);
            var g = parseInt(color.substr(3, 2), 16);
            var b = parseInt(color.substr(5, 2), 16);
            return new Array(r, g, b);
        },
        //颜色值从 rgb 到 #xxxxxx
        rgb2color: function(rgb) {
            var s = "#";
            for (var i = 0; i < 3; i++) {
                var c = Math.round(rgb[i]).toString(16);
                if (c.length == 1) {
                    c = '0' + c;
                }
                s += c;
            }
            return s.toUpperCase();
        },

        // 生成渐变  
        gradient: function(step, colorA, colorB) {
            var doughnutChart = [];
            var Gradient = new Array(3);
            var A = this.color2rgb(colorA);
            var B = this.color2rgb(colorB);
            for (var i = 0; i <= step; i++) {

                for (var c = 0; c < 3; c++) {
                    // RGB通道分别进行计算        
                    Gradient[c] = A[c] + (B[c] - A[c]) / step * i;
                }
                doughnutChart[i] = {
                    value: 1,
                    color: this.rgb2color(Gradient)
                };
            }
            return doughnutChart;
        }

    }));

    $(function() {
        new Page();
    });
});