define(['zepto', 'C', 'view'], function($, C, View) {
    'use strict';

    var Page = View.extend(_.extend({
        tagName: '',
        className: '',
        el: 'body',
        events: {
            'tap .support-bank': 'showSupportBank',
            'tap .icon-back': 'hideSupportBank',
            'tap .link-pro .v_ys': 'showAgreement',
            'tap .link-pro .v_fast': 'showFastAgreement',
            'tap .bind-agreement .close-x': 'hideAgreement',
            'tap .bind-fast-agreement .close-x': 'hideFastAgreement',
            'tap #btn_card' : 'goBindCard',
            'input #card_input' :'checkBankNum',
        },
        // 实例化后默认初始化该方法
        initialize: function () {
            var self = this;
            self.versionName = '';
            //获取用户信息
            self.userdata = C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO) || {};
            
            /*
             *保存调用H5绑卡的产品的信息
             *在绑卡结果页根据产品进行不同的结果操作
             */
            self.production = decodeURIComponent(C.Utils.getParameter("production")) || '';
            self.saveKey = decodeURIComponent(C.Utils.getParameter("saveKey")) || '';
            var returnUrl = decodeURIComponent(C.Utils.getParameter("returnUrl")) || '';
            var cardConf = {
                production:self.production,
                saveKey:self.saveKey,
                returnUrl:returnUrl
            };
            C.Utils.data(C.Constant.DataKey.HOME_BIND_CARD_CONF, cardConf);
            
            /*
             *根据production来区分不同的loanType
             */
            self.loanType = C.Constant.PRODUCTION.CODE;
            if (self.production == 'iloan') {
                self.loanType = '1';
            } else if (self.production == 'zed') {
                self.loanType = '2';
            } else if (self.production == 'keplerSDK') {
                self.loanType = '1';
            }
            /*
             *设置头部
             *from标识来自于H5绑卡
             */
            C.Native.setHeader({
                title:C.Constant.TITLE.BIND_CARD,
                leftCallback:function(){
                    C.Native.back({
                        url:'',
                        data:{
                            from:'bindCard'
                        }
                    });
                }
            });
            //获取版本号
            C.Native.getAppVersion(function(data){
                self.versionName = data.versionName;
            });

            //获取设备信息
            C.Native.getDeviceInfo(function(data){
                if(C.Flag.SUCCESS == data.code){
                    self.deviceInfo = data.result || '';
                    self.MachineSN = self.deviceInfo ? self.deviceInfo.MachineSN : '';
                    C.Utils.data(C.Constant.DataKey.DEVICE_INFO, data.result);
                } else {
                    self.deviceInfo = '';
                    self.MachineSN = '';
                    C.Utils.data(C.Constant.DataKey.DEVICE_INFO, '');
                }
            });
            
            //获取城市信息
            C.Native.getCityName(function(data){
                if (!!data.cityName) {
                    self.cityName = data.cityName || '';
                    C.Utils.data(C.Constant.DataKey.CITY_NAME, data.cityName);
                } else {
                    self.cityName = '';
                    C.Utils.data(C.Constant.DataKey.CITY_NAME, '');
                }
            });
            C.UI.stopLoading();
        },
        //数字键盘,四位空格
        checkBankNum:function(e){
            var $target = $('#card_input');
            //兼容android4.2的input中光标不在最后面问题
            var val = $target.val().replace(/[^0-9]/g,'').replace(C.Utils.RegexMap.bankCardNo,'$1 ');
            
            $target.val('');
            $target.val(val);
            
            setTimeout(function () {
                if ($target[0].setSelectionRange) {
                    $target[0].setSelectionRange(val.length,val.length);  
                    $target.focus();
                }
            },10);
        },
        // 渲染整个view
        render: function (bindCardList) {
            var html = _.template($('#content-tpl').html())({data:bindCardList});
            this.bankListEl.html(html);  
        },
        //查看支持银行
        showSupportBank:function(){
            var self = this,
                userdata = C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO) || {};
            
            C.UI.loading();
            var param = {
                    curVer: self.versionName || '',
                    machineSN:self.MachineSN || '',
                    loanType:self.loanType
            };
            $.ajax({
                url:C.Api.QUERY_BANKCARD_LIST,
                type:'get',
                data:param,
                success:function(res){
                    if(res.flag == C.Flag.SUCCESS && res.data){
                        var bankList = res.data.bankList;
                        var allBankName = "";
                        for(var i in bankList){
                            allBankName += bankList[i].bankName+"、";
                        }
                        
                        $(".support-banklist").show().find("p").html(allBankName.substring(0,allBankName.length-1));
                    }
                    C.UI.stopLoading();
                },
                error:function(res){
                    C.Native.tip(res.msg);
                    C.UI.stopLoading();
                }
            });
        },
        hideSupportBank: function () {
            $(".support-banklist").hide();
        },
        //显示协议
        showAgreement: function(){
            var self = this;
            $("#show_card_authorizion_div").show();
        },
        showFastAgreement:function(){
           
            $("#show_fast_payment_div").show();
        },
        //隐藏协议
        hideAgreement: function(e){
            $("#show_card_authorizion_div").hide();
        },
        hideFastAgreement: function(e){
            $("#show_fast_payment_div").hide();
        },
        goBindCard: function () {
            C.UI.loading();
            $('#card_input').blur();
            var self = this;
            var cardNoN = $.trim($("#card_input").val());
            var	cardNo  = cardNoN.replace(/\s+/g,"");
            //TODO:银行卡号校验+如果没有平安付token需要去手动登录注册壹钱包
            if (self.userdata.paPayToken) {
                if(cardNo && C.Utils.RegexMap.CardNo.test(cardNo)){
                    C.Native.updatePapayToken(self.userdata.paPayToken,function (data) {
                        if (data.code == '1') {
                            C.UI.loading();
                            self.userdata.paPayToken = data.paPayToken;
                            C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO, self.userdata);
                            //客户账户制和i贷在ss绑卡时需要设备信息和城市信息,zed不需要
                            if (self.production !== 'zed') {
                                if(self.deviceInfo){
                                    if (self.cityName) {
                                        self.getToken(cardNo);
                                    } else {
                                        C.UI.stopLoading();
                                        C.Native.tip('无法获取当前城市，请允许定位重新尝试');
                                    }
                                } else {
                                    C.UI.stopLoading();
                                    C.Native.tip('无法获取设备信息');
                                }
                            } else {
                                self.getToken(cardNo);
                            }
                        } else {
                            C.UI.stopLoading();
                            C.Native.tip('平安付token更新失败');
                        }
                    });
                } else {
                    C.UI.stopLoading();
                    C.Native.tip("请输入格式正确的银行卡号");
                }
            } else {
                C.UI.stopLoading();
                C.Native.tip('该用户没有平安付token');
            }
            
        },
        getToken: function(cardNo){
            var self = this, 
                userdata = self.userdata;
            self.cardNo = cardNo;
            
            var param = {
                curVer : self.versionName,
                token : userdata.token,
                machineSN : self.MachineSN || '',
                pafToken : userdata.paPayToken,
                cardNo : C.rsaEncrypt(cardNo),
                loanType : self.loanType,
                name : C.rsaEncrypt(userdata.custName) ,
                certId : C.rsaEncrypt(userdata.Id) ,
                mobileNo : C.rsaEncrypt(userdata.mobile),
                endDecVer : '1.0.0'
            };
            
            $.ajax({
                url:C.Api.QUERY_CARD_INFO,
                type:"post",
                data:param,
                success:function(res){
                    if(C.Flag.SUCCESS == res.flag && res.data){
                        res.data.cardNo = self.cardNo;
                        C.Utils.data(C.Constant.DataKey.CARD_DATA, res.data);
                        self.bindCard(res.data);
                    }else{
                        C.UI.stopLoading();
                    }
                },
                error:function(){
                    C.UI.stopLoading();
                }
            });
            
        },
        bindCard: function(data){
            var self = this;
            C.Native.setHeader({
                title:C.Constant.TITLE.BIND_CARD,
                isBack:false
            });
            //中转地址
            //var jumpUrl = "http://nts-tms-dmzstg1.pingan.com.cn:9027/html-dev/paem_public/publicForward.html",
            var jumpUrl = "http://txt.pingan.com.cn/static/paem/public/publicForward.html",
                returnhref = jumpUrl + '?forwardUrl=bind-card-result.html&production=' + self.production + '&saveKey=' + self.saveKey,
                cancelhref = jumpUrl + '?forwardUrl=bind-card.html&production=' + self.production + '&saveKey=' + self.saveKey;
            
            var paramData = {
                    merchantNo : data.merchantNo,
                    version : "1.0",
                    returnUrl : returnhref,
                    cancelUrl : cancelhref,
                    requestMsg : data.requestMsg,
                    requestNo : data.requestNo
                };
            var _form = document.getElementsByTagName("form");
            _form[0].setAttribute("method","post");
            _form[0].setAttribute("action",C.Constant.PAPAY_BIND_CARD + '?_t=' + (+ new Date()));
            document.getElementsByName("merchantNo")[0].setAttribute("value",paramData.merchantNo);
            document.getElementsByName("version")[0].setAttribute("value",paramData.version)
            document.getElementsByName("returnUrl")[0].setAttribute("value",paramData.returnUrl)
            document.getElementsByName("cancelUrl")[0].setAttribute("value",paramData.cancelUrl)
            document.getElementsByName("requestMsg")[0].setAttribute("value",paramData.requestMsg)
            document.getElementsByName("requestNo")[0].setAttribute("value",paramData.requestNo)
            _form[0].submit();
        }
    }));
    $(function() {
        new Page();
    });
});
