/*!
 * common模块提供zed_H5的所有基础功能以及环境初始化
 * @module common
 * @author 周一平 
 * @history 2015-6-10 add
 */
define([
    "zepto",
    // 基础库 不依赖其他模块
    "js/common/env",
    "js/common/utils",
    "js/common/api",
    "js/common/flag",
    "js/common/constant",
    "js/common/native",
    "js/common/talkingdata",
    "js/common/ui",
    // 业务库，组装业务功能
    "js/common/account",
    "js/common/init",
    "libs/jsencrypt",
    "js/common/debug"
], function(
    $,
    EnvJson,
    Utils,
    Api,
    Flag,
    Constant,
    Native,
    TD,
    UI,
    Account,
    init,
    JSEncrypt,
    debug
) {
    // Encrypt with the public key...
    var RSAENCRYPT = new JSEncrypt();
    // encrypt.setPublicKey($("#pubkey").val());
    RSAENCRYPT.setPublicKey("-----BEGIN PUBLIC KEY-----\nMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDwHQU77tsMBNbKnzVd+OZeINs7\nrPgGdV8owrau1Ox9a5axrJ2nak3dDQiD9Zt/UfkckZhqFYhDmzxYOgkYDmoP4fTM\neqIwY4e0m4+WDTF6Ef74tEW2SeNwUVqBtcKD+DGEx9QTaWjOLu+wIw4f4gRuuro2\n7oSctyNJfiJ625C32QIDAQAB\n-----END PUBLIC KEY-----");
    
    /**
     * 定义与Native相关的事件监听
     */
    $$.EventListener = {
        /**
         * 返回（点击返回按钮或Android物理返回键）
         * @param url
         */
        onBack: function (url,data) {
            Native.getUserInfo(function(data){
                Utils.data(Constant.DataKey.USER_LOGIN_INFO, data);
                
            });
        },
        /**
         * 返回 (客户端登录状态发生变化后)
         */
        onRefresh: function () {
            Native.getUserInfo(function(data){
                Utils.data(Constant.DataKey.USER_LOGIN_INFO, data);
                location.reload();
            });

        },
        //页面重新出现调用，包括native的返回
        pageDidAppear: function () {
            Native.getUserInfo(function(data){
                Utils.data(Constant.DataKey.USER_LOGIN_INFO, data);
            });
        },
        //页面离开时调用
        pageDidDisappear: function () {
            Native.getUserInfo(function(data){
                Utils.data(Constant.DataKey.USER_LOGIN_INFO, data);
            });
        }
    } 
    
    // 判断是否已经登录
    var C = {
        // SS环境变量
        Env: EnvJson.ssEnv,
        // 平安付环境变量
        pafEnv: EnvJson.pafEnv,
        // API
        Api: Api,
        // API
        Flag: Flag,
        // 常量
        Constant: Constant,
        // 工具类
        Utils: Utils,
        // Native接口
        Native: Native,
        // Talking埋点
        TD: TD,
        // UI控件
        UI: UI,
        // 帐户
        Account: Account,
        debug:debug,
        // 校验
        Validator: {
            // 验证手机号
            mobileNo: function (mobileNo) {
                // 判断非空
                if (!mobileNo) {
                    return {result: false, error: "手机号码不能为空"};
                }
                // 判断是否符合规则
                else if (!Utils.RegexMap.MobileNo.test(mobileNo)) {
                    return {result: false, error: "手机号码格式错误"};
                }
                return {result: true};
            },
            /*
             验证证件号码
             01: 居民身份证
             02/03/04: 军官证/士兵证/护照
             05/06: 港澳通行证或台胞证
             07: 其他
             */
            idNo: function (idType,idNo) {
                var checkResult = {result: true};
                var formatErrorResult = {result: false, error: "证件号码格式错误"};

                if (!idNo) {
                    checkResult = {result: false, error: "证件号码不能为空"};
                } else {
                    switch (idType) {
                        // 身份证：15或18位字符
                        case "01" :
                            if(idNo.length == 15){
                                checkResult = {result: false, error: "请输入18位身份证号"};
                            }
                            else if (!(Utils.RegexMap.idCard.test(idNo) && Utils.strDateTime(idNo.substr(6,8)))) {
                                checkResult = formatErrorResult;
                            }
                            break;
                        // 护照 2
                        // 士兵证
                        // 军官证：6-50位字符(可输中文)
                        case '02' :
                        case '03' :
                        case '04' :
                            if (!/^[\u4e00-\u9fa5a-zA-Z\d]{6,50}$/.test(idNo)) {
                                checkResult = formatErrorResult;
                            }
                            break;
                        // 港澳台回乡证或台胞证: 5-50位字符，只允许大写字母和数字，最多输入50位
                        case "05" :
                        case "06" :
                            if (!/^[A-Z\d]{5,50}$/.test(idNo)) {
                                checkResult = formatErrorResult;
                            }
                            break;
                        default :
                            // 其他：3-50位字符，最多输入50位
                            if (!/^[a-zA-Z\d]{3,50}$/.test(idNo)) {
                                checkResult = formatErrorResult;
                            }
                            break;
                    }
                }
                return checkResult;
            },
            /**
             * [checkAgeRangeByIdCardNo 根据身份证校验年龄是否再范围内，闭区间]
             * @param  {[type]} idCardNo [身份证]
             * @param  {[type]} maxAge   [最大年龄]
             * @param  {[type]} minAge   [最小年龄]
             * @return {[type]}          []
             */
            checkAgeRangeByIdCardNo: function(idCardNo, minAge, maxAge) {
                if (this.idNo("01", idCardNo).result) {
                    return this.checkAgeRange(idCardNo.substr(6, 8), minAge, maxAge);
                } else {
                    return false;
                }
            },
            checkAgeRange: function(birthday, minAge, maxAge) {
                var maxAge = Number(maxAge), minAge = Number(minAge);
                var d = /^(\d{4})(\d{2})(\d{2})$/.exec(birthday);
                //最大最小年龄正常 且身份证格式正确
                if (d && minAge >= 0 && maxAge >= 0 && maxAge >= minAge) {

                    var max = new Date(Number(d[1]) + maxAge + 1, Number(d[2]) - 1, Number(d[3])).getTime(),
                        min = new Date(Number(d[1]) + minAge, Number(d[2]) - 1, Number(d[3])).getTime(),
                        now = Date.now();
                    return now < max && now > min;
                } else {
                    return false;
                }
            }
        },
        rsaEncrypt:function(text){
            return RSAENCRYPT.encrypt(text);
        },
        // 获取用户信息
        getUserInfo:function(callback){
            if (EnvJson.ssEnv == 'DEVELOPMENT') {
                var loginData = Utils.data(C.Constant.DataKey.USER_LOGIN_INFO);
                if(!loginData || !loginData.accountId){
                    Native.getUserInfo(function(data){
                        Utils.data(C.Constant.DataKey.USER_LOGIN_INFO, data);
                        callback && callback(data);
                    });
                }else{
                    callback && callback(loginData);
                }
            } else {
                Native.getUserInfo(function(data){
                    Utils.data(C.Constant.DataKey.USER_LOGIN_INFO, data);
                    callback && callback(data);
                });
            }
        },
        operZedData:function (itemList) {
            itemList = itemList?itemList:[];
            var list = [];
            var codeToMap = {
                "1000": "1",
                "3000": "2",
                "3100": "2",
                "3200": "2",
                "3300": "2",
                "3400": "2",
                "3500": "3",
                "7000": "4",
                "7100": "4",
                "7200": "4",
                "7300": "4",
                "7400": "4",
                "7500": "5",
                "7800": "5",
                "4600": "5",
                "4800": "8",
                "1100": "6",
                "410000": "6",
                "420000": "6",
                "430000": "6",
                "800100": "7",
                "500000": "13"
            };
            //根据还款状态（loanStatus） 映射 申请单显示状态(statusMap)
            var newcodeToMap = {
                "0": "8",
                "1": "12",
                "2": "9"
            };

            var statusMap = {
                "1": "申请中",
                "2": "审批中",
                "3": "金额确认中",
                "4": "办押中",
                "5": "放款中",
                "6": "已取消",
                "7": "拒绝",
                "8": "还款中",
                "9": "已结清",
                "10": "代偿",
                "11": "已撤押",
                "12": "已逾期",
                "13": "回退",
                "14": "待撤押"
            };

            for (var i = 0;i<itemList.length;i++) {
                var item = itemList[i];
                var statusCode = 0;
                if (item.revokeFlag == "2") {
                    statusCode = 14;
                } else if (item.revokeFlag == "3") {
                    statusCode = 11;
                } else {
                    try {
                        statusCode = newcodeToMap[item.loanStatus] ? Number(newcodeToMap[item.loanStatus]) : Number(codeToMap[item.applyStatus]);
                    } catch(e) {
                        statusCode = 0;
                    }
                }

                var statusName = statusMap[statusCode] || '';
                var money = 0,
                    moneyText = '';
                //确定金额
                if (statusCode == 3) {
                    money = C.Utils.formatMoney(item.approvalMoney) || '--';
                    moneyText = '审批金额(元)';
                    
                } else if (statusCode == 4 || statusCode == 5 || statusCode == 6 || statusCode == 9 || statusCode == 11 || statusCode == 14) {
                    money = C.Utils.formatMoney(item.approvalMoney) || '--';
                    moneyText = '申请金额(元)';
                } else if (statusCode == 8 || statusCode == 12) {
                    money = C.Utils.formatMoney(item.payAmount) || '--';
                    moneyText = '本期还款金额(元)';
                } else if (statusCode == 10) {
                    money = C.Utils.formatMoney(item.compensateMoney) || '--';
                    moneyText = '代偿金额(元)';
                } else if (statusCode == 1 || statusCode == 2 || statusCode == 7 || statusCode == 13) {
                    money = C.Utils.formatMoney(item.applyMoney) || '--';
                    moneyText = '申请金额(元)';
                } 

                //借款金额
                var balanceMoney =  item.balanceMoney ? parseFloat(item.balanceMoney.replace(/,/g, '')) : 0;

                list.push({
                    statusCode:statusCode,
                    statusName:statusName,
                    money:money,
                    moneyText:moneyText,
                    balanceMoney:balanceMoney
                });
            }
            return list;
        },
        operBorrowData: function (data) {
            var obj = {
                totalMoney : 0,
                borrowList : [],
                counts : 0,
                lastMoney : 0,
                lastDate : ''
            };
            data = data?data:{};
            var dataList = data.lnSumLst || false;
            
            if (dataList && dataList.length>0) {
                for (var i=0;i<dataList.length;i++) {
                    //信保产品
                    if (dataList[i].applType == 'XB') {
                        var xbObj = {
                            productId : 'xbyd',
                            productName : '信保易贷',
                            productStatus : '无抵押',
                            iconClass : C.Constant.ICON.XB
                        };
                        if (dataList[i].status == 'AP') {
                            $.extend(xbObj,{
                                status : 'AP',
                                moneyStatus : '申请中',
                                money : C.Utils.formatMoney(dataList[i].applAmt,2),
                                moneyText : '申请金额(元)',
                                term : dataList[i].term
                            });
                            
                            obj.borrowList.push(xbObj);
                        } else if (dataList[i].status == 'RP') {
                            $.extend(xbObj,{
                                status : 'RP',
                                moneyStatus : '还款中',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                moneyText : '贷款金额(元)'
                            });
                            
                            obj.borrowList.push(xbObj);
                            obj.totalMoney += parseFloat(dataList[i].leftPrin.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].rpAmt || 0;
                            }
                        } else if (dataList[i].status == 'OD') {
                            $.extend(xbObj,{
                                status : 'OD',
                                moneyStatus : '已逾期',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                moneyText : '贷款金额(元)',
                                overMoney : C.Utils.formatMoney(dataList[i].dueAmt,2),
                                overDay : dataList[i].overDay
                            });
                            
                            obj.borrowList.push(xbObj);
                            obj.totalMoney += parseFloat(dataList[i].leftPrin.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].dueAmt || 0;
                            }
                        } else if (dataList[i].status == 'FP') {
                            $.extend(xbObj,{
                                status : 'FP',
                                moneyStatus : '已还清',
                                money : dataList[i].amt,
                                month : dataList[i].term
                            });
                            
                            obj.borrowList.push(xbObj);
                        }
                    } else if (dataList[i].applType == 'FD') {
                        var xbObj = {
                            productId : 'fdyd',
                            productName : '富登易贷',
                            productStatus : '无抵押',
                            iconClass : C.Constant.ICON.XB
                        };
                        if (dataList[i].status == 'AP') {
                            $.extend(xbObj,{
                                status : 'AP',
                                moneyStatus : '申请中',
                                money : C.Utils.formatMoney(dataList[i].applAmt,2),
                                moneyText : '申请金额(元)',
                                term : dataList[i].term
                            });
                            
                            obj.borrowList.push(xbObj);
                        } else if (dataList[i].status == 'RP') {
                            $.extend(xbObj,{
                                status : 'RP',
                                moneyStatus : '还款中',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                moneyText : '贷款金额(元)'
                            });
                            
                            obj.borrowList.push(xbObj);
                            obj.totalMoney += parseFloat(dataList[i].leftPrin.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].rpAmt || 0;
                            }
                        } else if (dataList[i].status == 'OD') {
                            $.extend(xbObj,{
                                status : 'OD',
                                moneyStatus : '已逾期',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                moneyText : '贷款金额(元)',
                                overMoney : C.Utils.formatMoney(dataList[i].dueAmt,2),
                                overDay : dataList[i].overDay
                            });
                            
                            obj.borrowList.push(xbObj);
                            obj.totalMoney += parseFloat(dataList[i].leftPrin.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].dueAmt || 0;
                            }
                        } else if (dataList[i].status == 'FP') {
                            $.extend(xbObj,{
                                status : 'FP',
                                moneyStatus : '已还清',
                                money : dataList[i].amt,
                                month : dataList[i].term
                            });
                            
                            obj.borrowList.push(xbObj);
                        }
                    } else if (dataList[i].applType == 'WX') {
                        //网销(i贷)产品
                        var wxObj = {
                            productId : 'idai',
                            productName : 'i贷',
                            productStatus : '无抵押',
                            iconClass : C.Constant.ICON.WX
                        };
                        if (dataList[i].status == 'AP') {
                            $.extend(wxObj,{
                                status : 'AP',
                                moneyStatus : '申请中',
                                money : C.Utils.formatMoney(dataList[i].creditAmt,2),
                                moneyText : '授信额度(元)',
                                fpdate : C.Utils.parseDateFormat(dataList[i].FPDate)
                            });
                            obj.borrowList.push(wxObj);
                        } else if (dataList[i].status == 'RP') {
                            $.extend(wxObj,{
                                status : 'RP',
                                moneyStatus : '还款中',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].usedAmt,2),
                                moneyText : '贷款金额(元)'
                            });
                            obj.borrowList.push(wxObj);
                            obj.totalMoney += parseFloat(dataList[i].usedAmt.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].rpAmt || 0;
                            }
                        } else if (dataList[i].status == 'OD') {
                            $.extend(wxObj,{
                                status : 'OD',
                                moneyStatus : '已逾期',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].dueAmt,2),
                                moneyText : '贷款金额(元)',
                                overMoney : C.Utils.formatMoney(dataList[i].dueAmt,2),
                                overDay : dataList[i].overDay
                            });
                            obj.borrowList.push(wxObj);
                            obj.totalMoney += parseFloat(dataList[i].dueAmt.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].rpAmt || 0;
                            }
                        }
                    }
                }
                obj.counts = obj.borrowList.length;
                obj.totalMoney = C.Utils.formatMoney(obj.totalMoney,2);
            }

            return obj;
        },

        operXBFDBorrowData: function (data) {
            var obj = {
                totalMoney : 0,
                borrowList : [],
                counts : 0,
                lastMoney : 0,
                lastDate : ''
            };
            data = data?data:{};
            var dataList = data.lnSumLst.resultObj || false;

            //console.log(dataList);
            
            if (dataList && dataList.length>0) {
                for (var i=0;i<dataList.length;i++) {
                    //信保产品
                    if (dataList[i].applType == 'XB') {
                        var xbObj = {
                            productId : 'xbyd',
                            productName : '信保易贷',
                            productStatus : '无抵押',
                            iconClass : C.Constant.ICON.XB,
                        };
                        if (dataList[i].status == 'AP') {
                            $.extend(xbObj,{
                                status : 'AP',
                                moneyStatus : '申请中',
                                money : C.Utils.formatMoney(dataList[i].applAmt,2),
                                moneyText : '申请金额(元)',
                                term : dataList[i].term
                            });
                            
                            obj.borrowList.push(xbObj);
                        } else if (dataList[i].status == 'RP') {
                            $.extend(xbObj,{
                                status : 'RP',
                                moneyStatus : '还款中',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                moneyText : '贷款金额(元)',
                                repayMoney : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                repayDate : C.Utils.parseDateFormat(dataList[i].rpDate)
                            });
                            
                            obj.borrowList.push(xbObj);
                            obj.totalMoney += parseFloat(dataList[i].leftPrin.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].rpAmt || 0;
                            }
                        } else if (dataList[i].status == 'OD') {
                            $.extend(xbObj,{
                                status : 'OD',
                                moneyStatus : '已逾期',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                moneyText : '贷款金额(元)',
                                overMoney : C.Utils.formatMoney(dataList[i].dueAmt,2),
                                overDay : dataList[i].overDay,
                                repayMoney : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                repayDate : C.Utils.parseDateFormat(dataList[i].rpDate),
                                repayOverMoney : C.Utils.formatMoney(dataList[i].dueAmt,2),
                                repayOverDay : C.Utils.parseDateFormat(dataList[i].overDay)
                            });
                            
                            obj.borrowList.push(xbObj);
                            obj.totalMoney += parseFloat(dataList[i].leftPrin.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].dueAmt || 0;
                            }
                        } else if (dataList[i].status == 'FP') {
                            $.extend(xbObj,{
                                status : 'FP',
                                moneyStatus : '已还清',
                                money : dataList[i].amt,
                                month : dataList[i].term
                            });
                            
                            obj.borrowList.push(xbObj);
                        }
                    } else if (dataList[i].applType == 'FD') {
                        var xbObj = {
                            productId : 'fdyd',
                            productName : '富登易贷',
                            productStatus : '无抵押',
                            iconClass : C.Constant.ICON.XB,
                        };
                        if (dataList[i].status == 'AP') {
                            $.extend(xbObj,{
                                status : 'AP',
                                moneyStatus : '申请中',
                                money : C.Utils.formatMoney(dataList[i].applAmt,2),
                                moneyText : '申请金额(元)',
                                term : dataList[i].term
                            });
                            
                            obj.borrowList.push(xbObj);
                        } else if (dataList[i].status == 'RP') {
                            $.extend(xbObj,{
                                status : 'RP',
                                moneyStatus : '还款中',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                moneyText : '贷款金额(元)',
                                repayMoney : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                repayDate : C.Utils.parseDateFormat(dataList[i].rpDate)
                            });
                            
                            obj.borrowList.push(xbObj);
                            obj.totalMoney += parseFloat(dataList[i].leftPrin.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].rpAmt || 0;
                            }
                        } else if (dataList[i].status == 'OD') {
                            $.extend(xbObj,{
                                status : 'OD',
                                moneyStatus : '已逾期',
                                date : C.Utils.parseDateFormat(dataList[i].rpDate),
                                dateText : '最后还款日',
                                money : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                moneyText : '贷款金额(元)',
                                overMoney : C.Utils.formatMoney(dataList[i].dueAmt,2),
                                overDay : dataList[i].overDay,
                                repayMoney : C.Utils.formatMoney(dataList[i].leftPrin,2),
                                repayDate : C.Utils.parseDateFormat(dataList[i].rpDate),
                                repayOverMoney : C.Utils.formatMoney(dataList[i].dueAmt,2),
                                repayOverDay : C.Utils.parseDateFormat(dataList[i].overDay)
                            });
                            
                            obj.borrowList.push(xbObj);
                            obj.totalMoney += parseFloat(dataList[i].leftPrin.replace(/,/g, ''));
                            //判断最新一笔还款
                            if (dataList[i].rpDate > obj.lastDate) {
                                obj.lastDate = dataList[i].rpDate;
                                obj.lastMoney = dataList[i].dueAmt || 0;
                            }
                        } else if (dataList[i].status == 'FP') {
                            $.extend(xbObj,{
                                status : 'FP',
                                moneyStatus : '已还清',
                                money : dataList[i].amt,
                                month : dataList[i].term
                            });   
                            obj.borrowList.push(xbObj);
                        }
                    }
                }
                obj.counts = obj.borrowList.length;
            }
            return obj;
        },

        operWXBorrowData: function (data) {
            var obj = {
                totalMoney : 0,
                borrowList : [],
                counts : 0,
                lastMoney : 0,
                lastDate : ''
            };

            if(!data) {
                return obj;
            }

            var dataList = [];
            dataList.push(data);
            
            if (dataList && dataList.length>0) {
                for (var i=0;i<dataList.length;i++) {

                    //网销(i贷)产品
                    var wxObj = {
                        productId : 'idai',
                        productName : 'i贷',
                        productStatus : '无抵押',
                        iconClass : C.Constant.ICON.WX
                    };
                    if (dataList[i].subProcessCode == 'AM' ||
                        dataList[i].subProcessCode == 'AF' ||
                        dataList[i].subProcessCode == 'AC' ||
                        dataList[i].subProcessCode == 'AY') {
                        $.extend(wxObj,{
                            status : 'AP',
                            moneyStatus : '申请中',
                            money : C.Utils.formatMoney(dataList[i].creditAmt,2),
                            moneyText : '授信额度(元)',
                            //fpdate : C.Utils.parseDateFormat(dataList[i].FPDate)
                            fpdate : C.Utils.parseDateFormat(dataList[i].cmpDate)
                        });
                        obj.borrowList.push(wxObj);
                    } else if (dataList[i].subProcessCode == 'AP' ||
                        dataList[i].subProcessCode == 'TD') {
                        $.extend(wxObj,{
                            status : 'AP',
                            moneyStatus : '已申请',
                            money : C.Utils.formatMoney(dataList[i].creditAmt,2),
                            moneyText : '授信额度(元)',
                            //fpdate : C.Utils.parseDateFormat(dataList[i].FPDate)
                            fpdate : C.Utils.parseDateFormat(dataList[i].cmpDate)
                        });
                        obj.borrowList.push(wxObj);
                    } else if (dataList[i].subProcessCode == 'RP') {
                        var showMoney = 0;
                        var dateLabel = '最后还款日';
                        var dateVal = '';

                        //还款列表信息
                        var repayMoneyVal = 0;
                        var repayDateVal = '';

                        if(dataList[i].loanCode == '0101-01') {
                            showMoney = dataList[i].loanAmt;
                            dateLabel = '到期还款日';
                            dateVal = dataList[i].currentDueDate;

                            repayMoneyVal = dataList[i].rpAmt;
                            repayDateVal = dataList[i].currentDueDate;
                        }
                        else {
                            showMoney = dataList[i].usedAmt;
                            dateVal = dataList[i].rpDate;

                            repayMoneyVal = dataList[i].usedAmt;
                            repayDateVal = dataList[i].rpDate;
                        }

                        $.extend(wxObj,{
                            status : 'RP',
                            moneyStatus : '还款中',
                            date : C.Utils.parseDateFormat(dateVal),
                            dateText : dateLabel,
                            money : C.Utils.formatMoney(showMoney,2),
                            moneyText : '贷款金额(元)',
                            repayMoney : C.Utils.formatMoney(repayMoneyVal,2),
                            repayDate : C.Utils.parseDateFormat(repayDateVal)
                        });
                        obj.borrowList.push(wxObj);
                        obj.totalMoney += parseFloat(showMoney.replace(/,/g, ''));
                        //判断最新一笔还款
                        if (dateVal > obj.lastDate) {
                            obj.lastDate = dateVal;
                            obj.lastMoney = dataList[i].rpAmt || 0;
                        }
                    } else if (dataList[i].subProcessCode == 'OD') {
                        var showMoney = 0;
                        var dateLabel = '最后还款日';
                        var dateVal = '';

                        //还款列表信息
                        var repayMoneyVal = 0;
                        var repayDateVal = '';
                        var repayOverMoneyVal = 0;
                        var repayOverDayVal = '';

                        if(dataList[i].loanCode == '0101-01') {
                            showMoney = dataList[i].currentDueAmt;
                            dateLabel = '到期还款日';
                            dateVal = dataList[i].currentDueDate;

                            repayMoneyVal = dataList[i].rpAmt;
                            repayDateVal = ataList[i].currentDueDate;
                            repayOverMoneyVal = ataList[i].currentDueAmt;
                            repayOverDayVal = ataList[i].overDueDay;
                        }
                        else {
                            showMoney = dataList[i].dueAmt;
                            dateVal = dataList[i].rpDate;

                            repayMoneyVal = dataList[i].dueAmt;
                            repayDateVal = ataList[i].rpDate;
                            repayOverMoneyVal = ataList[i].dueAmt;
                            repayOverDayVal = ataList[i].overDay;
                        }

                        $.extend(wxObj,{
                            status : 'OD',
                            moneyStatus : '已逾期',
                            date : C.Utils.parseDateFormat(dateVal),
                            dateText : '最后还款日',
                            money : C.Utils.formatMoney(showMoney,2),
                            moneyText : '贷款金额(元)',
                            overMoney : C.Utils.formatMoney(showMoney,2),
                            overDay : dataList[i].overDay,
                            repayMoney : C.Utils.formatMoney(repayMoneyVal,2),
                            repayDate : C.Utils.parseDateFormat(repayDateVal),
                            repayOverMoney : C.Utils.formatMoney(repayOverMoneyVal,2),
                            repayOverDay : C.Utils.parseDateFormat(repayOverDayVal)
                        });
                        obj.borrowList.push(wxObj);
                        obj.totalMoney += parseFloat(showMoney.replace(/,/g, ''));
                        //判断最新一笔还款
                        if (dateVal > obj.lastDate) {
                            obj.lastDate = dateVal;
                            obj.lastMoney = dataList[i].rpAmt || 0;
                        }
                    }
                }
                obj.counts = obj.borrowList.length;
            }
            return obj;
        },
        operCarLifeData: function (data) {
            var obj = {
                totalMoney : 0,
                carlifeList : [],
                counts : 0,
                lastMoney : 0,
                lastDate : ''
            };
            data = data?data:{};
            var dataList = data || false;
            
            if (dataList) {
                if (dataList.loanType == '14') {
                    var czObj = {
                        productId : 'czd',
                        isCheShou : dataList.isCheShou,
                        creditLine : dataList.creditLine == null ? "最高15万" : C.Utils.formatMoney(dataList.creditLine,2),
                        productName : '车主贷',
                        productStatus : '无抵押',
                        iconClass : Constant.ICON.car
                    };
                    if (dataList.applStatus == '0') {
                        $.extend(czObj,{
                            applStatus : '0',
                            moneyStatus : '申请中',
                            moneyText : '申请金额(元)'
                        });
                        obj.carlifeList.push(czObj);
                    } else if (dataList.applStatus == '1') {
                        $.extend(czObj,{
                            applStatus : '1',
                            moneyStatus : '待放款',
                            moneyText : '贷款金额(元)'
                        });
                        obj.carlifeList.push(czObj);
                    } else if (dataList.applStatus == '2') {
                        $.extend(czObj,{
                            applStatus : '2',
                            moneyStatus : '已放款',
                            moneyText : '贷款金额(元)'
                        });        
                        obj.carlifeList.push(czObj); 
                        // obj.totalMoney += parseFloat(dataList.creditLine.replace(/,/g, ''));
                    } else if (dataList.applStatus == '3') {
                        $.extend(czObj,{
                            applStatus : '3',
                            moneyStatus : '还款中',
                            moneyText : '贷款金额(元)'
                        });        
                        obj.carlifeList.push(czObj);
                        // obj.totalMoney += parseFloat(dataList.creditLine.replace(/,/g, ''));
                    }
                } else if (dataList.loanType == '15') {
                    var sxObj = {
                        productId : 'sxd',
                        isCheShou : dataList.isCheShou,
                        creditLine : dataList.creditLine == null ? "最高15万" : C.Utils.formatMoney(dataList.creditLine,2),
                        productName : '寿险贷',
                        productStatus : '无抵押',
                        iconClass : Constant.ICON.life
                    };
                    if (dataList.applStatus == '0') {
                        $.extend(sxObj,{
                            applStatus : '0',
                            moneyStatus : '申请中',
                            moneyText : '申请金额(元)'
                        });
                        
                        obj.carlifeList.push(sxObj);
                    } else if (dataList.applStatus == '1') {
                        $.extend(sxObj,{
                            applStatus : '1',
                            moneyStatus : '待放款',
                            moneyText : '贷款金额(元)'
                        });
                        obj.carlifeList.push(sxObj);
                    } else if (dataList.applStatus == '2') {
                        $.extend(sxObj,{
                            applStatus : '2',
                            moneyStatus : '已放款',
                            moneyText : '贷款金额(元)'
                        });        
                        obj.carlifeList.push(sxObj);
                        // obj.totalMoney += parseFloat(dataList.creditLine.replace(/,/g, ''));
                    } else if (dataList.applStatus == '3') {
                        $.extend(sxObj,{
                            applStatus : '3',
                            moneyStatus : '还款中',
                            moneyText : '贷款金额(元)'
                        });  
                        obj.carlifeList.push(sxObj);
                        // obj.totalMoney += parseFloat(dataList.creditLine.replace(/,/g, ''));
                    }
                }
                obj.counts = obj.carlifeList.length;
            }
            return obj;
        }
    };
    // 获取用户信息
    C.getUserInfo(function(){
        init.apply(this);
    });
    //获取设备信息
    C.Native.getDeviceInfo(function(data){
        if(C.Flag.SUCCESS == data.code){
            Utils.data(C.Constant.DataKey.DEVICE_INFO, data.result);
        } else {
            Utils.data(C.Constant.DataKey.DEVICE_INFO, '');
        }
    });
    //获取埋点信息
    C.Native.getTalkingDataMsg(function(data){
        Utils.data(C.Constant.DataKey.DEVICE_MER_RESERVED, data);
    });
    //获取城市信息
    C.Native.getCityName(function(data){
        if (!!data.cityName) {
            Utils.data(C.Constant.DataKey.CITY_NAME, data.cityName);
        } else {
            Utils.data(C.Constant.DataKey.CITY_NAME, '');
        }
    });
    return C;
})
