/*!
 * 初始化 common子模块
 * @module init
 * @author 周一平 
 * @history 2015-6-10 add
 */
define([
    "zepto",
    "js/common/env",
    "js/common/flag",
    "js/common/constant",
    "js/common/utils",
    "js/common/ui",
    "js/common/native",
    "js/common/account",
    "js/common/api",
    ],function(
        $,
        EnvJson,
        Flag,
        Constant,
        Utils,
        UI,
        Native,
        account,
        Api
        ){
    return function(){
        var data = {}, 
            Env = EnvJson.ssEnv;

        //备份扩展ajax方法
        var _ajax = $.ajax,
            _ajaxExt = {
                error: function() {
                    if(Env != 'DEVELOPMENT'){
                        Native.tip("网络异常，请稍后再试！");
                    }else{
                        UI.error({
                            content:"网络异常，请稍后再试！"
                        });
                    }
                },
                success: function(res) {
                    try {
                        // 登录超时的时候跳转到登录页
                        if (res.flag == Flag.LOGIN_TIMEOUT || res.flag == Flag.ERROR) {
                            account.logout();
                            if (Env != 'DEVELOPMENT') {
                                Native.dealTimeOut(res.msg);
                            } else {
                                var url = "login.html?redirectURL=" + encodeURIComponent(location.href);
                                UI.error({
                                    content: res.msg,
                                    ok: function() {
                                        location.href = url;
                                    }
                                });
                            }
                        } else {
                            if (res.flag && res.flag != Flag.SUCCESS) {
                                var code = res.flag;
                                // 集合内的code值不提示
                                var whiteCode = [""];

                                if (res.msg && ($.inArray(code, whiteCode) == -1)) {
                                    if (Env != 'DEVELOPMENT') {
                                        Native.tip(res.msg);
                                    } else {
                                        UI.error({
                                            content: res.msg
                                        });
                                    }
                                }
                            }
                        }
                    } catch (e) {}
                }
            };
        
        //重写扩展ajax方法
        $.ajax = function(opt) {
            //备份opt中error和success方法
            var fn = {
                error: opt.error || function(XMLHttpRequest, textStatus, errorThrown) {},
                success:opt.success,
                complete: opt.complete || function(XHR, TS) {}
            }

            //扩展增强处理
            var _opt = $.extend(opt, {
                error: function(XMLHttpRequest, textStatus, errorThrown) {
                    //执行自定义方法之后  再执行扩展方法
                    fn.error(XMLHttpRequest, textStatus, errorThrown);
                    _ajaxExt.error(XMLHttpRequest, textStatus, errorThrown);
                },
                success: function(data) {
                    fn.success(data);
                    _ajaxExt.success(data);
                },
                complete: function(XHR, TS) {
                    fn.complete(XHR, TS);
                    //_ajaxExt.complete(XHR, TS);
                },
                data:opt.data || {},
                type:opt.type || 'get',
                timeout:600000 //设置请求超时时间为10分钟
            });
            
            if (Env == 'DEVELOPMENT' || Env=="TEST"  || Env=="STG1" || Env=="STG2" || Env=="STG3") {
                _ajax(_opt);
            }else{
                var loginInfo = Utils.data(Constant.DataKey.USER_LOGIN_INFO);
                if(loginInfo){ 
                    $.extend(_opt.data,{
                        accountId:loginInfo.accountId,
                        token:loginInfo.token,
                        os:App.IS_IOS ? "IOS" : "A"
                    });
                }
                Native.request(_opt);
            }
        };

        $.ajaxSettings.cache = false;
        // 超时 15000ms
        $.ajaxSettings.timeout = 10000000;
        $.ajaxSettings.type = 'GET';
        $.ajaxSettings.dataType = 'json';
        $.ajaxSettings.beforeSend = function(xhr,settings){
            var paramObject = {};
            var loginInfo = Utils.data(Constant.DataKey.USER_LOGIN_INFO);
            var os = App.IS_IOS ? "IOS" : "A";
            if(loginInfo){
                paramObject["accountId"] = loginInfo.accountId;
                paramObject["token"] = loginInfo.token;
            }
            paramObject["os"] = os;
            // console.log(paramObject);
            if (settings.url.indexOf("?") != -1) {
                settings.url += ("&" + $.param(paramObject));
            } else {
                settings.url += ("?" + $.param(paramObject));
            }
        };
    }
});