define(["js/common/utils"], function (Utils) {
    var App = window.App || {};
    var defaultCallback = function () {
    };
    return {
        /**
         * 发送HTTP请求
         * @import jQuery|Zepto
         * @param options 对象{type:"get",data:{},successCallBack:function(res){},failCallBack:function(res){}}
         * @param .data JSON对象 请求入参
         * @param .type 字符串 请求方式，默认get
         * @param .success 函数 function(){} 请求成功处理
         * @param .error  函数 function(){} 请求失败处理
         */
        request: function (options) {
            var data = options.data || {},
                param = [],
                type = options.type || 'get';
            if (!/^get|post$/.test(type)) {
                type = 'get';
            }

            if (data && typeof data == 'object') {
                for (var key in data) {
                    try {
                        param.push(key + '=' + encodeURIComponent(decodeURIComponent(data[key])));
                    } catch (e) {
                        param.push(key + '=' + encodeURIComponent(data[key]));
                    }
                }

                data = param.join('&');
            }
            App.call('request', options.url, type, options.headers || '', data, options.success, options.error);
        },
        /**
         * 发送HTTP GET请求（调用C.Native.request）
         * @param options 对象
         * 默认get方式 方法参照request
         */
        get: function (options) {
            options.type = 'get';
            this.request(options);
        },
        /**
         * 发送HTTP POST请求（调用C.Native.request）
         * @param options 对象
         * 默认post方式 方法参照request
         */
        post: function (options) {
            options.type = 'post';
            this.request(options);
        },
        /**
         * WebView跳转（本地页面、服务端页面、及模块）
         * @param options 对象 {title:"",url:""}
         * .url 字符串 跳转的链接
         * .defaultCallback 函数 function(){} 请求处理
         * 跳转参数
         */
        forward: function (options) {
            var data = options.data,
                url = options.url;

            if (data) {
                data = $.param(data);
                if (url.indexOf('?') > -1) {
                    url += '&' + data;
                } else {
                    url += '?' + data;
                }
            }

            // PC的跳转方式
            if (!(App.IS_WP || App.IS_ANDROID || App.IS_IOS)) {
                location.href = url;
                return;
            }

            /*
             *过滤param
             */
            if (url && url.indexOf('?') > -1) {
                var param = [],
                    urlHost = url.split("?")[0],
                    urlData = Utils.getQueryMap(url);
                for (var key in urlData) {
                    var tmp = '';
                    try {
                        tmp = decodeURIComponent(urlData[key]);
                    } catch (e) {
                        tmp = urlData[key];
                    }
                    param.push(key + '=' + encodeURIComponent(tmp));
                }
                url = urlHost + "?" + param.join("&");
            }

            url = url.replace(/(%2F)/ig, "/");
            App.call('forward', url, options.callBack || '');
        },
        /**
         * WebView跳转,跳转到其他模块的页面
         * @param options 对象 {title:"",url:""}
         * .url 字符串 跳转的链接
         * .defaultCallback 函数 function(){} 请求处理
         * 跳转参数
         */
        forwardModule: function (options) {
            var data = options.data,
                module = options.module,
                url = options.url;

            if (data) {
                data = $.param(data);
                if (url.indexOf('?') > -1) {
                    url += '&' + data;
                } else {
                    url += '?' + data;
                }
            }

            // PC的跳转方式
            if (!(App.IS_WP || App.IS_ANDROID || App.IS_IOS)) {
                location.href = url;
                return;
            }

            /*
             *过滤param
             */
            if (url && url.indexOf('?') > -1) {
                var param = [],
                    urlHost = url.split("?")[0],
                    urlData = Utils.getQueryMap(url);
                for (var key in urlData) {
                    var tmp = '';
                    try {
                        tmp = decodeURIComponent(urlData[key]);
                    } catch (e) {
                        tmp = urlData[key];
                    }
                    param.push(key + '=' + encodeURIComponent(tmp));
                }
                url = urlHost + "?" + param.join("&");
            }

            url = url.replace(/(%2F)/ig, "/");
            App.call('forwardModule', module, url, options.callBack || '');
        },
        /*
        *跳转至外部浏览器
         */
        forwardByBrowse: function (options) {
            var url = options.url;
            App.call("forwardByBrowse",url);
        },
        /**
         * WebView返回
         * @param options {url:""}
         * .url back返回的url,为空默认返回上一个页面,
         * .data 返回后Native调用C.Service.onback()事件, 并将参数data传递给onback方法
         *                如果返回到流程开始的的页面,需要传页面名字,如"info_loan.html"
         * .defaultCallback 函数 function(){} 请求处理
         */
        back: function (options) {
            var options = options || {},
                url = "",
                data = "",
                model = options.model || "";

            if (options && options.url) {
                url = options.url;

                if (/^https*:\/\//.test(url)) {
                    //
                } else {
                    url = url;
                }
            }
            if (options && options.data) {
                data = options.data;
            }
            this.getAppVersion(function (res) {
                if (res.version >= 410) {
                    /**
                     * 页面返回，同时支持模块间的返回
                     * @param mid 要返回到的模块，“”表示当前模块
                     * @param url 要返回的url，mid和url同时为空时，返回上一页，mid不为空，url为空，返回指定模块
                     * @param data 要返回的数据，只有WebView间的返回才有用
                     * @param callBack
                     */
                    App.call('backWithMid', model, url || "", data || "", options.callBack || '');
                } else {
                    App.call('back', url || "", data || "", options.callBack || '');
                }
            });
        },
        /**
         * 页面返回，同时支持模块间的返回
         * @param mid 要返回到的模块，“”表示当前模块
         * @param url 要返回的url，mid和url同时为空时，返回上一页，mid不为空，url为空，返回指定模块
         * @param data 要返回的数据，只有WebView间的返回才有用
         * @param callBack
         */
        backWithMid: function (options) {
            var options = options || {},
                url = "",
                data = "",
                model = options.model || "";

            if (options && options.url) {
                url = options.url;

                if (/^https*:\/\//.test(url)) {
                    //
                } else {
                    url = url;
                }
            }
            if (options && options.data) {
                data = options.data;
            }

            App.call('backWithMid', model, url || "", data || "", options.callBack || '');
        },
        /**
         * 设置头部信息
         * @param options {title:"标题",isBack:true,leftCallback:function(){},isClose:true,closeCallback:function(){}}
         * .title 字符串 设置头部标题
         * .isBack 布尔值 是否有返回图标
         * .leftCallback function(){} 函数 设置左边回调
         * .rightText 布尔值 是否有关闭图标
         * .rightIcon  function(){} 函数 设置右边回调
         * .rightCallback function(){} 函数 设置右边回调
         * .data 扩展数据 Json格式  如：isFullScreen(是否全屏)
         */
        setHeader: function (options) {
            var leftCallback = options.leftCallback || '',
                rightCallback = options.rightCallback || '';
            if (typeof options.isBack == "undefined") {
                options.isBack = true;
            }
            App.call('setHeader', options.title || '', !!options.isBack, leftCallback, options.rightText, options.rightIcon || '', rightCallback, options.data || '');
        },
        /**
         * 显示加载动画 C.UI.loading();
         * options.msg 当不允许取消加载动画时 提示信息
         */
        loadingBegin: function (options) {
            var msg = '';

            if (options) {
                msg = options.msg;
            }

            App.call('loadingBegin', msg);
        },
        loadingBeginNew: function (options, cacelable) {
            var msg = '';

            if (options) {
                msg = options.msg;
            }

            App.call('loadingBegin', msg, cacelable);
        },
        /**
         * 关闭加载动画 C.UI.stopLoading();
         */
        loadingFinish: function () {
            App.call('loadingFinish');
        },
        /**
         * 补充身份信息
         * */
        addUserInfo:function(callback){
        	App.call("addUserInfo", callback || defaultCallback)
        },
        /**
         * 提示
         * .text 字符串 C.Native.tip('提示内容');
         */
        tip: function (text) {
            var text = text || '';
            console.log(text);
            App.call('tip', text);
        },
        /**
         * 监听用户操作数据
         * @param eventId 事件分类
         * @param eventLable事件 事件类型细分
         * @param jsonData 数据
         */
        TDOnEvent: function (options) {
            var options = options || {};
            App.call("TDOnEvent", options.eventId || '', options.eventLable || '', options.jsonData || '');
        },
        /**
         * 绑定银行卡
         * @return {[type]} [description]
         { code:”1”,           //1表示绑卡成功，0表示失败
             data:{userId:"userId",
                bankCardNo:"bankCardNo",
                phoneNum:"phoneNum",
                bankMark:"bankMark",
                bankCardType:"bankCardType",
                bankName:"bankName”
             }
         }
         */
        bindBankCard: function (token, callBack) {
            App.call("bindCard", token || "", callBack || defaultCallback);
        },
        /**
         * 选择地区
         * @param callback 对过callback的data将地区信息通过data传递给H5，
         * data格式{"province":"广东省","city":"深圳市","zone":"八卦岭"}
         */
        selectAddressInfo: function (callBack) {
            App.call("selectAddressInfo", callBack || defaultCallback);
        },
        /**
         * 开放地区的选择
         * @param callback 对过callback的data将地区信息通过data传递给H5，
         * data格式{"province":"广东省","city":"深圳市","zone":"八卦岭"}
         */
        selectAddressInfoPort: function (callBack) {
            App.call("selectAddressInfoPort", callBack || defaultCallback);
        },
        /**
         * 显示日期选择控件
         * @param title 选泽日期的标题，默认为“选择日期”
         * @param showYear 是否显示年份  Y|N
         * @param showMonth 是否显示月  Y|N
         * @param showDay 是否显示日期  Y|N
         * @param pos 弹框的显示位置，bottom｜center｜top
         * @param callback js回调
         * {
         *    "year":"2015",//根据Y｜N来判断是否返回该值
         *    "month":"2",
         *    "day":"28"
         * }
         */
        showDatePikerDialog: function (options) {
            App.call("showDatePikerDialog", options.title || '选择日期', options.showYear || 'Y', options.showMonth || 'Y', options.showDay || 'Y', options.pos || 'bottom', options.callBack || defaultCallback);
        },
        /**
         * 扫描身份证
         * @param  {[type]} callBack [description]
         * @return {[type]}
         * {
         *    userName:"userName",       //名字
         *    idCardNuber:"idCardNuber", //身份证号
         *    sex:"sex"                  //性别
         *  }
         */
        idCardScanning: function (callBack) {
            App.call("idCardScanning", callBack || defaultCallback);
        },
        /**
         * 跳转至i贷页面
         */
        jumpToILoanHome: function () {
            App.call("jumpToILoanHome");
        },
        /**
         * 获取当前用户的登录信息
         * 返回当前用户的登录信息，以json形式返回
         *
         {
         "custName": "dapeng",
         "account": "abcd",
         "msgCnt": "12",
         "token": "ad3bjlaoe00jbmbm",
         "custId": "399444",
         "mobile": "1312929400",
         "city": "",
         "cityName": "深圳",
         "sysDate": "",
         "ad": user.getAd,
         "paPayToken":"ad3bjlaoe00jbmbm",
         "platform": "android",
         "accountId":"",
         "mark": "BN"
         "id": "",
         "pointsSwitch": "",
         "isOrangebankCust": "",
         "InvitationCode": "",
         "isNew": "",
         "machineId": ""
         }
         */
        getUserInfo: function (callback) {
            App.call("getUserInfo", callback || defaultCallback);
        },

        /**
         * 设置用户的当前信息，注意，会将传递的值覆盖现有值。
         * @param userInfo 需要设置的用户信息（可以只提供需要设置的信息如｛"acountId","abcd"｝）
         * @param callback 设置成功返回1，失败返回0
         */
        setUserInfo: function (userInfo) {
            var userInfo = userInfo || {};
            App.call("setUserInfo", userInfo);
        },
        /**
         * 登录超时接口。在弹出的dialog中点击确定后，跳转到登录页面登录
         * @param msg 弹出登录超时提示框中显示的信息。默认显示“登录超时，请重新登录”
         */
        dealTimeOut: function (msg) {
            var msg = msg || '';
            App.call("dealTimeOut", msg);
        },
        /**
         * Native测试事件
         */
        titleClick: function (callback) {
            App.call("titleClick", callback || defaultCallback);
        },
        /**
         * 静默注册壹钱包，失败时让用户手动去壹钱包页面注册
         * @param customName 客户姓名
         * @param id 客户身份证号码
         */
        registPafInBack: function (custName, idNum) {
            App.call("registPafInBack", custName || '', idNum || '');
        },
        /**
         * 跳转到某个Native界面
         * page: 界面名称
         * data: 传递数据
         */
        gotoNative: function (page, data, callback) {
            App.call('gotoNative', page, data || '', callback || defaultCallback);
        },

        prepaidRecharge: function (page, data, callback) {
            console.log('call prepaidRecharge');
            App.call('prepaidRecharge', page, data || '', callback || defaultCallback);
        },
        /**
         * @return {"version":"311","versionName":"3.1.1"}
         */
        getAppVersion: function (callback) {
            App.call('getAppVersion', callback || defaultCallback);
        },
        /**
         * 用户是否登录
         * @param  {Function} callback [description]
         * @return Object     {flag:"1"}表示已登录,{flag:"0"}表示未登录
         */
        isLogined: function (callback) {
            App.call('isLogined', callback || defaultCallback);
        },
        logout: function (callback) {
            App.call('logout', callback || defaultCallback);
        },
        login: function (data, callback) {
            App.call('login', data, callback || defaultCallback);
        },
        /**
         * 获取一钱包资金数据
         * @param  {Function} callback [description]
         * @return {[type]}   {mainBalance:%@, hqBaoBalance:%@}余额,活钱包
         */
        getYiQianBaoBalance: function (callback) {
            App.call('getYiQianBaoBalance', callback || defaultCallback);
        },
        /**
         * 调用native打电话
         * @param  {string} phone 电话号码
         */
        call: function (phone) {
            App.call('call', phone || '');
        },
        //调起到拨号界面
        dial: function (phone) {
            App.call('dial', phone || '');
        },
        updateAppVersion: function (url, callback) {
            App.call('updateAppVersion', url, callback || defaultCallback);
        },
        /**
         * 获取设备信息
         * */
        getDeviceInfo: function (callback) {
            App.call("getBindCardParams", callback || defaultCallback)
        },
        /**
         * 获取注册页面设备信息
         * */
        getRegisterParams: function (callback) {
            App.call("paehome.getRegisterParams", callback || defaultCallback)
        },
        /**
         * 绑定微博、京东、1号店、淘宝
         */
        bindNetAccount:function(netAccountType,callback){
            App.call("bindNetAccount", netAccountType , callback || defaultCallback);
        },
         /**
         * 绑定社保、寿险、车险、公积金
         */
        bindInsuranceAccount:function(netAccountType,custNo,callback){
            App.call("bindInsuranceAccount", netAccountType , custNo, callback || defaultCallback);
        },
        /**
        
        /**
        *寿险拍照接口
        */
        nsurancePhotograph: function(netAccountNo, Num, accountId, authCode, callback){
            App.call("nsurancePhotograph",  netAccountNo,Num, accountId, authCode, callback || defaultCallback);
        },
        /*手机运营商验证*/
        bindNumber:function(acctNo,callback){
            App.call("bindNumber", acctNo , callback || defaultCallback);
        },
        /*天下通认证*/
        worldPass: function(txtwage, custNo,callback){
            App.call("worldPass", txtwage ,custNo, callback || defaultCallback);
        },
        /**
         * 平安付token换取新token
         * */
        updatePapayToken: function (oldPaPayToken, callback) {
            App.call("updatePapayToken", oldPaPayToken, callback || defaultCallback)
        },
        /**
         * 返回{"code":"1"} 1表示注册或登录壹钱包成功
         * */
        loginOrRegistPaOne: function (callback) {
            App.call("loginOrRegistPaOne", callback || defaultCallback);
        },
        /**获取当前所在的城市名{"cityName":"深圳市"}*/
        getCityName: function (callback) {
            App.call("getCityName", callback || defaultCallback);
        },
        //获取埋点信息
        getTalkingDataMsg: function (callback) {
            App.call("getTalkingDataMsg", callback || defaultCallback);
        },
        //跳转到一钱包
        jumpToYiQianBao: function (data, callback) {
            App.call("paehome.jumpToYiQianBao", data || '', callback || defaultCallback);
        },
        //iloan进行H5绑卡后的回调函数
        onBindCardCallBack: function (data, flag) {
            console.log(flag)
            App.call("paehome.onBindCardCallBack", data || '', flag || '0');
        },
        //获取android的渠道id
        getChannelId: function (callback) {
            App.call("getChannelId", callback || defaultCallback);
        },
        //TMX native调用
        getTMXSessionId: function (callback){
            console.log('call native getTMXSessionId');
            App.call("getTMXSessionId", callback || defaultCallback);
        },


        /**
         * 带上传功能的http请求
         * @param url
         * @param paramJson    普通参数
         * @param fileJson    要上传的文件的json
         * @param callback    如果后台有返回，就返回后台返回的数据，否则返回异常信息（String,如网络连接异常）
         */
        upload: function (url, paramJson, fileJson, callback) {
            App.call("upload", url, paramJson, fileJson, callback);
        }
    }
});
