/*!
 * Utils utils子模块
 * @module utils
 * @author 周一平 
 * @history 2015-6-10 add
 */
define(["underscore"], function(_) {
    var Utils = {
        RegexMap : {
            //制表符
            table: /\t/g,
            //换行符
            line: /\n/g,
            //正负整数或浮点数
            intOrFloat: /^(-)?\d+(\.\d+)?$/,
            //组织机构代码
            enterpriseCode:  /^[a-zA-Z0-9]{8}\-[a-zA-Z0-9]$/,
            //工商执照注册号
            enterpriseRegCode:  /^\d{13}$|^\d{15}$/,  //   以前是13位,08年以后变15位
            //身份证
            idCard:  /^\d{15}$|^\d{18}$|^\d{17}(\d|X|x)$/,
            // 手机号码
            MobileNo: /^1[34587]\d{9}$/,
            // 银行卡号（大于或等于16位的数字）
            CardNo: /^\d{16,}$/,
            // 短验证码（6位数字以上）
            MobileCode: /^\d{6,}$/,
            // 交易密码(6-16位数字或字母)
            OrderPassword: /^\S{6,16}$/,
            //千分位正则
            parseThousands: /(\d{1,3})(?=(\d{3})+(?:$|\.))/g,
            //每4位字符用空格隔开
            bankCardNo: /(\d{4})(?=\d)/g,
            //金额检测
            moneyTest: /^(0|[1-9]\d*)(\.\d{1,2})?$/,
            //卡号屏蔽
            parseToStarNumber: /^(\d{4})(\d+)(\d{4})$/,
            // 后四位屏蔽
            parseRightFourStar: /^(\w+)(\w{4})$/,
            //日期格式检测
            parseDateFormat: /\b(\d{4})\b[^\d]+(\d{1,2})\b[^\d]+(\d{1,2})\b(\s(\d{1,2})\:(\d{1,2})\:(\d{1,2}))?[^\d]?/,
            // 出生日期掩码，显示格式（"19**年**月*2日")
            userBirthdayStarRegex: /(\d{2})\d{2}([^\d]+)\d+([^\d]+)\d?(\d)([^\d]+)?/,
            //金额转换
            moneyReplace: /[^0-9\.]/g
        },
        RegexReplacement : {
            parseThousands: '$1,',
            parseToStarNumber: function ($0, $1, $2, $3) {
                return $1 + $2.replace(/\d/g, "*") + $3;
            },
            parseRightFourStar: function ($0, $1, $2) {
                return $1.replace(/\w/g, "*") + $2;
            }
        },
        /**
         * 日志打印方法
         * @param text 需要打印的日志内容
         */
        logs: function(text) {
            window.console && console.log && console.log(text);
        },
        parseThousands : function (priceVal) {
            return ((priceVal || '0') + '').replace(Utils.RegexMap.parseThousands, Utils.RegexReplacement.parseThousands);
        },
        parseToStarNumber : function (number) {
            return ((number || '0') + '').replace(Utils.RegexMap.parseToStarNumber, Utils.RegexReplacement.parseToStarNumber);
        },
        /**
         * 本地数据操作
         * @param key
         * @param value
         */
        data: function(key, value) {
            var getItemValue = function() {
                var data = localStorage.getItem(key);
                try {
                    data = JSON.parse(data);
                } catch (e) {
                    Utils.logs(e.message);
                }
                return data;
            };
            if (key && value === undefined) {
                return getItemValue();
            }else if(key && value === null){
                localStorage.removeItem(key);
            }else{
                localStorage.setItem(key, JSON.stringify(value));
            }
        },
        /**
         * 公共方法定义
         * @example: http://xxx.com/a.do?productCode=P001
         *     Result:  C.getParameter('productCode')  // 'P001'
         */
        getParameter : function (param) {
            var reg = new RegExp('[&,?,&amp;]' + param + '=([^\\&]*)', 'i');
            var value = reg.exec(location.search);
            return value ? value[1] : '';
        },
        /**
         * 获取URL参数对象
         * @param queryString
         * @returns {{}}
         */
        getQueryMap: function (queryString) {
            var paramObj = {},
                paramList,
                oneQueryMatch,
                regGlobal = /[\?\&][^\?\&]+=[^\?\&#]+/g,
                regOne = /[\?\&]([^=\?]+)=([^\?\&#]+)/;

            queryString = queryString || location.href;
            paramList = queryString.match(regGlobal);

            if (!paramList) {
                return paramObj;
            }

            for (var i = 0, len = paramList.length; i < len; i++) {
                oneQueryMatch = paramList[i].match(regOne);
                if (null === oneQueryMatch) {
                    continue;
                }
                paramObj[oneQueryMatch[1]] = oneQueryMatch[2];
            }

            return paramObj;
        },
        /**
         * 获取填写身份证相关的信息
         * @ param str 截取的出生日期字符串 或 身份证号
         * @ param type 传入第二个值是证明需返回的是string，否则是boolean
         * 检测身份证中的日期是否有效
         *
         */
        strDateTime: function (str,type){
            var type = type || '';
            // 如果传入的是身份证号时，从第6位开始截取8个字符
            if(str.length == 18){
                str = str.substr(6,8);
            }
            var r = str.match(/^(\d{1,4})(-|\/)?(\d{1,2})\2(\d{1,2})$/);
            if(r==null)return false;
            var d= new Date(r[1], r[3]-1, r[4]);
            var now = new Date();
            var minDate = new Date("1900-01-01"), maxDate = new Date(now.getFullYear(),now.getMonth(),now.getDate());
            // 如果不符合最大当前日期，最小1900年1月1日，则不通过日期校验
            if(d < minDate || d > maxDate){
                return false;
            }
            if(type){
                return d.getFullYear()+'年'+(d.getMonth()+1)+'月'+d.getDate()+'日';
            }

            return (d.getFullYear()==r[1]&&(d.getMonth()+1)==r[3]&&d.getDate()==r[4]);
        },
        // 判断对象中属性的值为空的个数
        isEmptyAttrValObject:function(obj){
            var count = 0;
            if(_.isArray(obj)){
                for(var i=0,len = obj.length;i<len;i++){
                    count = _.filter(obj[i], function(val){ return !!val == false;}).length;
                }
            }else{
                count = _.filter(obj, function(val){ return !!val == false;}).length;
            }
            return !!count; 
        },
        //金额格式化
        formatMoney: function(s, n){
        	if(!s) return s
        	n = n > 0 && n <= 20 ? n : 2;   
        	s = parseFloat((s + "").replace(/[^\d\.-]/g, "")).toFixed(n) + "";   
        	var l = s.split(".")[0].split("").reverse(),   
        	r = s.split(".")[1];   
        	t = "";   
        	for(i = 0; i < l.length; i ++ )   
        	{   
        		t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? "," : "");   
        	}   
        	return t.split("").reverse().join("") + "." + r;   
        },
        /** 转换日期格式
         * @param date : 日期格式|String类型 (如：'2012-12-12' | '2012年12月12日' | new Date())
         * @param format : String类型 （如: 'yyyy年MM月dd日'或'yyyy年MM月dd日 hh时mm分ss秒',默认'yyyy-MM-dd'）
         * @example C.parseDateFormat(new Date(), 'yyyy年MM月dd日') 输出："2014年04月29日"
         * @example C.parseDateFormat(new Date()) 输出："2014-04-29"
         * @exmaple C.parseDateFormat("2014-05-07 16:09:47","yyyy年MM月dd日 hh时mm分ss秒")
         *          输出："2014年05月07日 16时09分47秒"
         **/
        parseDateFormat:function (date, format) {
            if(!date){
                return date;
            }
            if(!isNaN(date) && String(date).length == 8){
                date = (date+'').replace(/^(\d{4})(\d{2})(\d{2})$/,"$1/$2/$3");
            }
            var addZero = function (val) {
                return /^\d{1}$/.test(val) ? '0' + val : val;
            };
            format = format || 'yyyy-MM-dd';
            var year = '', month = '', day = '', hours = "", minutes = "", seconds = "";
            if (typeof date == 'string') {
                var dateReg = Utils.RegexMap.parseDateFormat;
                var dateMatch = date.match(dateReg);
                if (dateMatch) {
                    year = dateMatch[1];
                    month = dateMatch[2];
                    day = dateMatch[3];
                    hours = dateMatch[5];
                    minutes = dateMatch[6];
                    seconds = dateMatch[7];
                }
            } else {
                year = date.getFullYear();
                month = date.getMonth() + 1;
                day = date.getDate();
                hours = date.getHours();
                minutes = date.getMinutes();
                seconds = date.getSeconds();
            }
            month = addZero(month);
            day = addZero(day);
            hours = addZero(hours);
            minutes = addZero(minutes);
            seconds = addZero(seconds);
            return format.replace('yyyy', year).replace('MM', month).replace('dd', day).replace("hh", hours).replace("mm", minutes).replace("ss", seconds);
        },
        /**
         * base64解码
         * @param {Object} str
         */
        base64decode: function (input) {
            var _keyStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=",
                output = "";
            var chr1, chr2, chr3;
            var enc1, enc2, enc3, enc4;
            var i = 0;
            if(!input)return input;
            input = input.replace(/[^A-Za-z0-9\+\/\=]/g, "");
            while (i < input.length) {
                enc1 = _keyStr.indexOf(input.charAt(i++));
                enc2 = _keyStr.indexOf(input.charAt(i++));
                enc3 = _keyStr.indexOf(input.charAt(i++));
                enc4 = _keyStr.indexOf(input.charAt(i++));
                chr1 = (enc1 << 2) | (enc2 >> 4);
                chr2 = ((enc2 & 15) << 4) | (enc3 >> 2);
                chr3 = ((enc3 & 3) << 6) | enc4;
                output = output + String.fromCharCode(chr1);
                if (enc3 != 64) {
                    output = output + String.fromCharCode(chr2);
                }
                if (enc4 != 64) {
                    output = output + String.fromCharCode(chr3);
                }
            }
            output = this.utf8_decode(output);
            return output;
        },
        // 解码成utf-8
        utf8_decode: function (utftext) {
            var string = "";
            var i = 0;
            var c = c1 = c2 = 0;
            while ( i < utftext.length ) {
                c = utftext.charCodeAt(i);
                if (c < 128) {
                    string += String.fromCharCode(c);
                    i++;
                } else if((c > 191) && (c < 224)) {
                    c2 = utftext.charCodeAt(i+1);
                    string += String.fromCharCode(((c & 31) << 6) | (c2 & 63));
                    i += 2;
                } else {
                    c2 = utftext.charCodeAt(i+1);
                    c3 = utftext.charCodeAt(i+2);
                    string += String.fromCharCode(((c & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
                    i += 3;
                }
            }
            return string;
        }
    }
    return Utils;
});
