define(['zepto', 'C', 'view', 'swiper', 'js/iloan'], function ($, C, View, Swiper, L) {
    'use strict';
    var Home = View.extend(_.extend({
        tagName: '',
        className: '',
        el: 'body',
        events: {
            'tap .borrow-money': 'borrowMoney',
            'tap .spend-money': 'spendMoney',
            'tap .make-money': 'makeMoney',
            'tap .quick-nav': 'goQuickNav',
            // 'tap .icon-speed': 'goIdai',
            'tap .icon-moreone': 'goTopup',
            'tap .icon-fast': 'goZed',
            'tap .icon-ipos': 'goIpos',
            'tap .icon-credit': 'goCredit',
            'tap .icon-score': 'goScore',
            'tap .sale-network': 'goSalesNetwork',
            'tap .withdraw': 'goWithdraw',
            'tap .icon-car': 'goCarLife',
            'click .swiper-img': 'jumpSwiper',
            'tap .add-loan-go': 'goAddLoan',
            'tap .add-loan-know': 'knowAddLoan',
            'tap .js_iloan': 'goIloan',
            'tap .js_xindai': 'goXindai'
        },
        // 实例化后默认初始化该方法
        initialize: function () {
            C.UI.loading();
            var self = this;
            /*
             *两个异步请求
             */
            self.requestSteps = 2;
            /*
             *设置定制的子项目
             */
            var quickNav = C.Utils.data(C.Constant.DataKey.HOME_QUICK_NAV) || [];
            self.userInfo = C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO) || {};
            /*
             *信用卡绑卡开关
             */
            self.attributeCredit = 'N';
            /*
             *是否有追加贷款资格;N没有Y有
             */
            self.addLoan = 'N';
            /*
             *获取首页轮播图及信用卡开关
             */
            $.ajax({
                type: "get",
                url: C.Api.HOME_CAROUSEL,
                data: {codeId: 'carousel_picture'},
                success: function (res) {
                    res = (typeof res == 'string') ? JSON.parse(res) : res;
                    if (C.Flag.SUCCESS == res.flag) {
                        //信用卡绑卡开关
                        self.attributeCredit = res.data.attribute || 'Y';
                        self.setQuickNav(quickNav);
                        self.render(res.data);
                    }
                    self.stopLoading();
                },
                error: function () {
                    self.stopLoading();
                }
            });
            /*
             *检测是否有追加贷款资格
             */
            C.Account.isLogin(function (data) {
                if (C.Flag.SUCCESS == data.flag) {
                    $.ajax({
                        type: "get",
                        url: C.Api.QUERY_ADD_LOAN_QUAL,
                        success: function (res) {
                            self.stopLoading();
                            if (C.Flag.SUCCESS == res.flag) {
                                if (res.data && res.data.isTopup == 'Y' && res.data.hasQualification == 'Y') {
                                    var data = res.data;
                                    //是否有追加贷款资格
                                    self.addLoan = 'Y';
                                    if (data.showTip == 'Y' && data.topupProgress == 0) {
                                        var obj = {
                                            name : self.userInfo.custName,
                                            money : (data.isCreditCust == 'Y' && data.creditLine > 0) ? data.creditLine : 0
                                        };
                                        var html = _.template($("#topup-tpl").html())(obj);
                                        $('.add-loan-sec').html(html).show();
                                    }
                                }
                            }
                        },
                        error: function () {
                            self.stopLoading();
                        }
                    });
                } else {
                    self.stopLoading();
                }
            });
        },
        // 渲染整个view
        render: function (data) {
            var self = this;
            var html = _.template($("#content-tpl").html())({data: data.imagesNameList});

            this.$el.find('.homeimg-banner').html(html);

            //设置轮播
            self.slide = Swiper('.swiper-container', {
                pagination: '.swiper-pagination',
                slidesPerView: 1,
                paginationClickable: true,
                loop: true,
                preloadImages: false,
                lazyLoading: true
            });
        },
        stopLoading: function () {
            var self = this;
            self.requestSteps--;
            if (self.requestSteps <= 0) {
                C.UI.stopLoading();
            }
        },
        borrowMoney: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.HOME_PAGE,
                eventLable: C.TD.Label.HOME_PAGE_0204
            });
            C.Native.forward({
                url: 'borrow-money.html'
            });
        },
        spendMoney: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.HOME_PAGE,
                eventLable: C.TD.Label.HOME_PAGE_0205
            });
            C.Native.forward({
                url: 'spend-money.html?attributeCredit=' + this.attributeCredit
            });
        },
        makeMoney: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.HOME_PAGE,
                eventLable: C.TD.Label.HOME_PAGE_0206
            });
            C.Native.forward({
                url: 'make-money.html'
            });
        },
        goQuickNav: function () {
            var self = this;
            C.Native.forward({
                url: 'quick-nav.html',
                data: {attributeCredit: self.attributeCredit}
            });
        },
        setQuickNav: function (data) {
            var self = this;
            for (var i = 0; i < data.length; i++) {
                data[i].icon = C.Constant.ICON[data[i].id];
            }
            var obj = {
                data: data,
                attributeCredit: self.attributeCredit,
                pointsSwitch: (self.userInfo.pointsSwitch == 'Y') ? 'Y' : 'N'
            };
            var html = _.template($('#features-tpl').html())(obj);
            $('.features').html(html);
        },
        goIdai: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.HOME_PAGE,
                eventLable: C.TD.Label.HOME_PAGE_02012
            });
            L.goIloan();
        },
        goAddLoan: function () {
            $('.add-loan-sec').hide();
            C.Native.gotoNative('iLoan');
        },
        knowAddLoan: function () {
            $('.add-loan-sec').hide();
            $.ajax({
                type: "get",
                url: C.Api.MESSAGE_NOT_TO_REMIND,
                success: function () {
                },
                error: function () {
                }
            });
        },
        goSalesNetwork: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.HOME_PAGE,
                eventLable: C.TD.Label.HOME_PAGE_02017
            });
            C.Native.gotoNative('salesNetwork');
        },
        goTopup: function () {
            var self = this;
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.HOME_PAGE,
                eventLable: C.TD.Label.HOME_PAGE_02014
            });
            C.Account.isLogin(function (data) {
                if (C.Flag.SUCCESS == data.flag) {
                    if (self.addLoan == 'Y') {
                        C.Native.gotoNative('iLoan');
                    } else {
                        C.Native.tip('暂时无法申请追加，请按时还款、累计信用，下次再试');
                    }
                } else {
                    C.Native.login({}, function () {
                        C.UI.loading();
                        $.ajax({
                            type: "get",
                            url: C.Api.QUERY_ADD_LOAN_QUAL,
                            success: function (res) {
                                C.UI.stopLoading();
                                if (C.Flag.SUCCESS == res.flag) {
                                    if (res.data && res.data.isTopup == 'Y' && res.data.hasQualification == 'Y') {
                                        C.Native.gotoNative('iLoan');
                                    } else {
                                        C.Native.tip('暂时无法申请追加，请按时还款、累计信用，下次再试');
                                    }
                                }
                            },
                            error: function () {
                                C.UI.stopLoading();
                            }
                        });
                    });
                }
            });
        },
        goZed: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.HOME_PAGE,
                eventLable: C.TD.Label.HOME_PAGE_02013
            });
            C.Native.forwardModule({
                module: 'zed',
                url: 'index_z_apply.html'
            });
        },

        /**
         * 清除iloan模块缓存数据
         * */
        clearIloanData: function() {
        	var keyjson = {
                    USER_LOGIN_INFO			:"ILOAN_USER_LOGIN_INFO",
                    PRODUCT_LIST_RES		:"ILOAN_PRODUCT_LIST_RES",
                    PRODUCT_LIST_RES_BANK   :"ILOAN_PRODUCT_LIST_RES_BANK",
                    SELECT_PRO_ITEM			:"ILOAN_SELECT_PRO_ITEM",
                    INFORMATION_TRIAL_RES	:"ILOAN_INFORMATION_TRIAL_RES",
                    BIND_ACCOUNT_LIST   	:"ILOAN_BIND_ACCOUNT_LIST",
                    LOAN_RESULT				:"ILOAN_RESULT",
                    INTO_SHAW_REPAY_PARAM   :"ILOAN_INTO_SHAW_REPAY_PARAM",
                    SHAWREPAYSCHEDULE		:"ILOAN_SHAWREPAYSCHEDULE",
                    INTOSHAWREPAYSCHEDULE	:"ILOAN_INTOSHAWREPAYSCHEDULE",
                    ILOANAPPLYNO			:"ILOAN_APPLYNO",
                    ILOAN_CUSTNO			:"ILOAN_CUSTNO",
                    ILOAN_BILLDAY			:"ILOAN_BILLDAY",
                    PRODUCT_TYPE			:"ILOAN_PRODUCT_TYPE",
                    CARD_DATA				:"ILOAN_CARD_DATA",
                    BEFORE_SOCIAL_OUTHER_HREF	:"ILOAN_BEFORE_SOCIAL_OUTHER_HREF",
                    NEED_CONTACT			:"ILOAN_NEED_CONTACT",
                    FACE_PARAM				:"ILOAN_FACE_PARAM",
                    FACE_STARTTIME			:"ILOAN_FACE_STARTTIME",
                    PHONE_AUTH_FLAG			:"ILOAN_PHONE_AUTH_FLAG",
                    LOANFAIL_CHANGE_TIME	:"ILOAN_FAIL_CHANGE_TIME",
                    CHOOSE_CARD_FROM		:"ILOAN_CHOOSE_CARD_FROM",
                    HASBINDED_CARD_INFO		:"ILOAN_HASBINDED_CARD_INFO",
                    BINDCARD_FROM_SELECT	:"ILOAN_BINDCARD_FROM_SELECT",
                    ACCOUNT_RESULT			:"ILOAN_ACCOUNT_RESULT",
                    REPAYMENT_RESULT		:"ILOAN_REPAYMENT_RESULT",
                    BIND_CARDS_LIST			:"ILOAN_BIND_CARDS_LIST",
                    SELECTCARD_FROM_LIST	:"ILOAN_SELECTCARD_FROM_LIST",
                    SHEBAO_CITY_LIST		:"ILOAN_SHEBAO_CITY_LIST",
                    BINDED_BINDNO			:"ILOAN_BINDED_BINDNO",
                    LOAN_FAIL_FROM_ACCOUNT	:"LOAN_FAIL_FROM_ACCOUNT",
                    LOAN_IS_OD				:"LOAN_IS_OD",
                    FAIL_RETRY_JSON			:"FAIL_RETRY_JSON",
                    FAIL_RETRY_BANKINFO		:"FAIL_RETRY_BANKINFO",
                    ILOAN_LOANSEQ			:"ILOAN_LOANSEQ",
                    ILOAN_EDIT_CONTACT		:"ILOAN_EDIT_CONTACT",
                    ILOAN_INDEX_TYPE		:"ILOAN_INDEX_TYPE",
                    ILOAN_INDEX_TIPMSG		:"ILOAN_INDEX_TIPMSG",
                    UPLOAD_CONTACT_NUM		:'ILOAN_UPLOAD_CONTACT_NUM'
        	};
			$.each(keyjson, function(key, value) {
				C.Utils.data(keyjson[key], null);
			})
        },

        clearXindaiData: function() {
            var keyjson = {
                // 我的账号详情页申请号applNo
                ACCOUNT_DETAIL_APPLNO: "XINDAI_ACCOUNT_DETAIL_APPLNO",
                // 我的账户详情页存储信息
                ACCOUNT_DETAIL: "XINDAI_ACCOUNT_DETAIL",
                // 壹钱包信息
                YIQIANBAO: "XINDAI_YIQIANBAO",
                QUERY_TOP_UP_CUSTOMER_INFO:"QUERY_TOP_UP_CUSTOMER_INFO",
                LUFAX_INFO:"LUFAX_INFO",
                // 追加贷款信息
                APP_INFO: "XINDAI_APP_INFO",
                // 富登还款还款金额
                FD_REPAY_AMT: "XINDAI_FD_REPAY_AMT",
                // 富登还款界面信息查询数据
                SEARCH_FD_PAY_BASEINFO: "XINDAI_FD_PAY_BASEINFO",
                // 信保还款界面信息查询数据
                SEARCH_PAY_BASEINFO: "XINDAI_SEARCH_PAY_BASEINFO",
                // 平安付token
                PAF_TOKEN: "XINDAI_PAPAF_TOKEN",
                // 壹钱包账户余额
                YIQIANBAO_BALANCE: "XINDAI_YIQIANBAO_BALANCE",
                // 查询追加贷款信息数据
                SEARCH_APPL_INFO: "XINDAI_SEARCH_APPL_INFO"
            };
            $.each(keyjson, function(key, value) {
                C.Utils.data(keyjson[key], null);
            });
        },

        goXindai: function() {
            L.goXindai();
        },

        goIloan: function() {
        	var _this = this;
        	/*C.Native.isLogined(function(data){
        		if(data.flag=="1"){
        			_this.iLoanClick();
        		}else{
        			C.Native.login({}, function(){});
        		}
        	})*/
        	C.Native.login({}, function(){
        		_this.iLoanClick();
        	});

        },

        iLoanClick: function() {
            var _this = this;
            C.UI.loading();
            _this.clearIloanData();
            C.Native.getUserInfo(function(data) {
                C.Utils.data("ILOAN_USER_LOGIN_INFO", data);
                C.Native.getCityName(function(result) {
                	var cityName = result.cityName;
                	if(!cityName){
                		C.Native.forwardModule({
                            module: 'iloan',
                			url: "try_get_cityname.html"
                		});
                		return false;
                	}else{
                		C.Utils.data("ILOAN_CITYNAME",cityName);
                	}
                    $.ajax({
                        url: C.Api.QUERY_USER_APPLY_STATE,
                        type: "post",
                        data: {
                            cityName: cityName
                        },
                        success: function(res) {
                            if (res.flag == "1" && res.data) {
                                var data = res.data;
                                if(data.resultCode == "1") {
                                	if(data.channelCodeFlag=="0"){
                                		C.Native.addUserInfo(function(res){
                							if(res.code=="1"){
                								C.Native.getUserInfo(function(data) {
                									C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO, data);
                									_this.iLoanClick();
                								});
                							}
                						});
                                	}else{

                                        //数据缓存
                                        if(data.productType) {
                                            C.Utils.data("ILOAN_PRODUCT_TYPE", data.productType);
                                        }
                                        if(data.applNo) {
                                            C.Utils.data("ILOAN_APPLYNO", data.applNo);
                                        }
                                        if(data.billDate) {
                                            C.Utils.data("ILOAN_BILLDAY", data.billDate);
                                        }
                                        if(data.custNo) {
                                            C.Utils.data("ILOAN_CUSTNO", data.custNo);
                                        }
                                        switch (data.subProcessCode) {
                                            case "AU":
                                            case "XX":
                                            case "RJ":
                                            case "AM":
                                            case "AF":
                                            case "AC":
                                            case "AY":
                                            	//跳转到产品介绍页：1、未鉴权，2、申请开关关闭，3、拒绝
                                            	C.Utils.data("ILOAN_INDEX_TYPE", data.subProcessCode);
                                            	C.Utils.data("ILOAN_INDEX_TIPMSG", data.resultMsg);
                                                C.Native.forwardModule({
                                                    module: 'iloan',
                                                    url: 'iloan_production_index.html'
                                                });
                                                break;
                                            case "AP":
                                                C.Native.forwardModule({
                                                    module: 'iloan',
                                                    url : 'credit_info_list.html'
                                                });
                                            	break;
                                            default:
                                                //TODO: 非授信环节申请状态处理
                                                C.Native.forwardModule({
                                                    module: 'iloan',
                                                    url: 'shaw_account.html'
                                                })
                                                break;
                                        }

                                	}
                                } else {
                                	C.UI.stopLoading();
                                    C.Native.tip(data.resultMsg);
                                }
                            } else {
                            	C.UI.stopLoading();
                            }
                        }
                    });
                });
            });
        },
        goIpos: function () {
            C.Native.forwardModule({
                module: 'ipos',
                url: 'index_e.html'
            });
        },
        goCarLife: function () {
            C.Native.forwardModule({
                module: 'carlife',
                url: 'index.html'
            });
        },
        goCredit: function () {
            C.Native.login({}, function () {
                C.Native.gotoNative('creditCardRepayment')
            });
        },
        goScore: function () {
            C.Native.login({}, function () {
                C.Native.forward({
                    url: 'my-score.html'
                });
            });
        },
        goWithdraw: function (e) {
            var self = this,
            //转入转出埋点
                isInto = $(e.target).hasClass('icon-change-into'),
                eventId = C.TD.Event.HOME_PAGE,
                eventLable = C.TD.Label.HOME_PAGE_02016;
            if (isInto) {
                eventId = C.TD.Event.HOME_PAGE;
                eventLable = C.TD.Label.HOME_PAGE_02015;
            }
            C.Native.TDOnEvent({
                eventId: eventId,
                eventLable: eventLable
            });
            //获取用户信息
            self.userInfo = C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO);
            C.Native.login({}, function () {
                //判断是否绑定平安付
                if (!!self.userInfo.paPayToken) {
                    C.Native.jumpToYiQianBao();
                } else {
                    C.Native.loginOrRegistPaOne(function () {
                        $$.EventListener.onRefresh();
                    });
                }
            });
        },
        //轮播图的点击跳转
        jumpSwiper: function (e) {
            var self = this,
                target = $(e.currentTarget),
                dataLink = target.attr('data-link');
            // 轮播图只埋前五个图片
            if (self.slide.clickedIndex <= 5) {
                C.Native.TDOnEvent({
                    eventId: C.TD.Event.HOME_PAGE,
                    eventLable: C.TD.Label['HOME_PAGE_020' + (self.slide.clickedIndex + 6)]
                });
            }
            switch (dataLink) {
                case 'spendmoney':
                    self.spendMoney();
                    break;
                case 'borrowmoney':
                    self.borrowMoney();
                    break;
                case 'makemoney':
                    self.makeMoney();
                    break;
                case 'ipos':
                    self.goIpos();
                    break;
                case 'zed':
                    self.goZed();
                    break;
                case 'iloan':
                    self.goIdai();
                    break;
                case 'topup':
                    self.goTopup();
                    break;
                default:
                    if (dataLink.indexOf('http://') == 0) {
                        C.Native.forward({
                            url: dataLink
                        });
                    }
            }
        }
    }));

    $(function () {
        var home = new Home();
        $$.EventListener.onRefresh = function () {
            C.Native.getUserInfo(function (data) {
                C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO, data);
                home.initialize();
            });
        }
    });
});
