define(['zepto', 'C', 'view', 'js/ipos'], function($, C, View, iPOS) {
    'use strict';
    
    var Page = View.extend(_.extend({
        tagName: '',
        className: '',
        el: 'body',
        events: {
            'tap .tab-list li' : 'tapTabList',
            'tap .quick-list .fr' : 'modifyQuickNav',
            'tap .icon-speed,.icon-moreone': 'goIdai',
            'tap .icon-fast': 'goZhaiedai',
            'tap .icon-ipos': 'goIpos',
            'tap .icon-credit': 'goCredit',
            'tap .icon-score': 'goScore'
        },
        // 实例化后默认初始化该方法
        initialize: function () {
            var self = this;
            self.quickNav = C.Utils.data(C.Constant.DataKey.HOME_QUICK_NAV) || [];
            self.quickNavIdList = [];
            $.each(self.quickNav,function (i,v) {
                self.quickNavIdList.push(v.id);
            });

            //获取信用卡开关
            self.attributeCredit = C.Utils.getParameter('attributeCredit') || 'N';
            
            //设置标题
            C.Native.setHeader({
                title:C.Constant.TITLE.QUICK_NAV,
                leftCallback:function(){
                    C.Native.back();
                },
                rightText: '完成',
                rightCallback: function(){
                    C.Utils.data(C.Constant.DataKey.HOME_QUICK_NAV,self.quickNav);
                    C.Native.back();
                }
            });

            $.ajax({
                type:"get",
                url:C.Api.QUICK_NAV,
                data:{codeId:'fastNavigate'},
                success:function(res){
                    res = (typeof res === 'string') ? JSON.parse(res) : res;
                    C.UI.stopLoading();
                    if (C.Flag.SUCCESS == res.flag) {
                        var data = res.data,
                            deleteCredit = '-1';
                        var deleteIpos = '-1';
                        for (var i = 0;i < data.earnList.length;i++) {
                            if($.inArray(data.earnList[i].id,self.quickNavIdList) > -1) {
                                data.earnList[i].added = '1';
                            } else {
                                data.earnList[i].added = '1';
                            }
                            data.earnList[i].icon = C.Constant.ICON[data.earnList[i].id];
                        }
                        for (var i = 0;i < data.borrowList.length;i++) {
                            //暂时屏蔽ipos
                            if(data.borrowList[i].id == 'ipos') {
                                deleteIpos = i;
                                continue;
                            }
                            if($.inArray(data.borrowList[i].id,self.quickNavIdList) > -1) {
                                data.borrowList[i].added = '1';
                            } else {
                                data.borrowList[i].added = '1';
                            }
                            data.borrowList[i].icon = C.Constant.ICON[data.borrowList[i].id];
                        }
                        if(deleteIpos !== '-1') {
                            data.borrowList.splice(deleteIpos, 1);
                        }
                        for (var i = 0;i < data.consumeList.length;i++) {
                            //判断是否显示信用卡还款
                            if(data.consumeList[i].id == 'credit' && self.attributeCredit == 'N') {
                                deleteCredit = i;
                                continue;
                            }
                            if($.inArray(data.consumeList[i].id,self.quickNavIdList) > -1) {
                                data.consumeList[i].added = '1';
                            } else {
                                data.consumeList[i].added = '1';
                            }
                            data.consumeList[i].icon = C.Constant.ICON[data.consumeList[i].id];
                        }
                        if(deleteCredit !== '-1') {
                            data.consumeList.splice(deleteCredit, 1);
                        }
                        self.render(data);
                    }
                }
            });
            C.UI.stopLoading();
        },
        // 渲染整个view
        render: function (data) {
            var obj = {
                borrowList: data.borrowList,
                consumeList: data.consumeList,
                earnList: data.earnList
            };
            var html = _.template($('#quick-nav-tpl').html())(obj);
            this.$el.find('.tab-con').html(html);
        },
        tapTabList: function (e) {
            var $target = $(e.currentTarget),
                dataName = $target.attr('data-name');
            $('.tab-list li').removeClass('active');
            $target.addClass('active');

            $('.tab-con-div').hide();
            $('.' + dataName).show();
        },
        modifyQuickNav: function (e) {
            return false;
            var self = this;
            var $target = $(e.currentTarget),
                dataId = $target.attr('data-id'),
                dataDesc = $target.attr('data-desc');
            if ($target.hasClass('btn-small')) {
                self.quickNav.push({
                    id: dataId,
                    desc: dataDesc
                });
                $target.removeClass('btn-small').addClass('btn-smallG').html('取消添加');
            } else {
                self.quickNav = self.quickNav.filter(function (item) {
                    return item.id !== dataId;
                });
                $target.removeClass('btn-smallG').addClass('btn-small').html(' + 添加');
            }
        },
        goIdai: function () {
            var self = this;
            if (self.logined) {
                C.Native.gotoNative('iLoan');
            } else {
                C.Native.gotoNative('login');
            }
        },
        goZhaiedai: function () {
            C.Native.forwardModule({
                module: 'zed',
                url: 'index_z_apply.html'
            });
        },
        goIpos: function () {
            iPOS.initIpos();
        },
        goCredit: function () {
            var self = this;
            if (self.logined) {
                //获取用户信息
                self.userInfo = C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO);
                C.Native.login({}, function () {
                    //判断是否绑定壹钱包
                    if (!!self.userInfo.paPayToken) {
                        C.Native.gotoNative('creditCardRepayment');
                    } else {
                        C.Native.loginOrRegistPaOne(function (json) {
                            if (C.Flag.SUCCESS == json.code) {
                                C.Native.getUserInfo(function(data){
                                    C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO, data);
                                    self.userInfo = data;
                                    if (!!self.userInfo.paPayToken) {
                                        C.Native.gotoNative('creditCardRepayment');
                                    }
                                });
                            }
                        });
                    }
                });
            } else {
                C.Native.gotoNative('login');
            }
        },
        goScore: function () {
            var self = this;
            if (self.logined) {
                C.Native.forward({
                    url: 'my-score.html'
                });
            } else {
                C.Native.gotoNative('login');
            }
        }
    }));

    $(function() {
        new Page();
    });
});