define(['zepto', 'C', 'js/component/identity','view'], function ($, C, Identity,View) {
    'use strict';

    var Page = View.extend(_.extend({
        tagName: '',
        className: '',
        el: 'body',
        events: {
            'tap .faq': 'goFAQ',
            'tap .online-customercare': 'goOnlineCustomerCare',
            'tap .customercare-phone': 'showCustomerCarePhone',
            'tap .sales-network': 'goSalesNetwork',
            'tap .account-management': 'goAccountManagement',
            'tap .feedback': 'goFeedback',
            'tap .login-section': 'goLogin',
            'tap .logout-btn': 'doLogout',
            'tap .hot-phone': 'callCustomerCarePhone',
            'tap .cancel-phone': 'cancelCustomerCarePhone',
            'tap .new-version': 'doUpdateVersion',
            'tap .newest-version': 'newestVersion',
            'tap .ctifi':'userctifi'
        },
        // 实例化后默认初始化该方法
        initialize: function () {
            C.UI.loading();
            var self = this;
            self.logined = false;
            //设置标题
            C.Native.setHeader({
                title: C.Constant.TITLE.SETTING,
                leftCallback: function () {
                    C.Native.back();
                }
            });

            self.userInfo = C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO);

            C.Account.isLogin(function (data) {
                if (C.Flag.SUCCESS == data.flag) {
                    self.logined = true;
                    //手机号中间四位加星号
                    if(self.userInfo.mobile){
                        var newNum = self.userInfo.mobile.substring(0,3)+"****"+self.userInfo.mobile.substring(7);
                    }

                    $('.login-section').hide();
                    $('.user-logined .username').html(self.userInfo.custName || '');

                    if(!!self.userInfo.custId){
                            $('.has-ctifi').show();
                            $('.ctifi').hide();
                    }else{
                            $('.ctifi').show();
                            $('.has-ctifi').hide();
                    };
                  
                    $('.user-logined .tel').html(newNum || '');
                    $('.user-logined,.logout-btn').show();
                } else {
                    $('.login-section').show();
                    $('.user-logined,.logout-btn').hide();
                }
                C.UI.stopLoading();
            });
            //设置版本信息
            C.Native.getAppVersion(function (data) {
                self.setAppVersion(data);
            });
        },
        userctifi:function(){
            var self = this;
            self.userInfo = C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO);
            
            if (!self.userInfo.custId) {
                    self.needIdentity();
                   /*C.Native.addUserInfo(function(res){
                        if(res.code=="1"){
                            C.Native.getUserInfo(function(data) {
                                C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO, data);
                            });
                    };
                });*/
                
            };
        },
        setAppVersion: function (data) {
            var self = this;
            self.$el.find('.app-version .version').html(data.versionName);
            var opr = App.IS_ANDROID ? 'A' : 'I';
            //请求版本更新
            $.ajax({
                type: "post",
                url: C.Api.UPDATE_VERSION,
                data: {"opr": opr, "ACCOUNT_VER": data.versionName},
                success: function (res) {
                    res = (typeof res === 'string') ? JSON.parse(res) : res;
                    if (C.Flag.SUCCESS == res.flag) {
                        self.$el.find('.app-version').find('.version').html(data.versionName);
                        if (opr === 'A' && res.data.ver > data.versionName && res.data.update == 'Y' && !!res.data.verUrl) {
                            self.$el.find('.app-version').addClass('new-version').find('.version').append('<sup class="reddot"></sup>');
                            self.newVersionUrl = res.data.verUrl;
                        } else {
                            self.$el.find('.app-version').addClass('newest-version');
                        }
                    }

                }
            });
        },
        doUpdateVersion: function () {
            var self = this;
            if (!!self.newVersionUrl) {
                C.Native.updateAppVersion(self.newVersionUrl);
            }
        },
        newestVersion: function () {
            // android版本提示
            if (App.IS_ANDROID) {
                C.Native.tip('已经更新到最新版本');
            }
        },
        goFAQ: function () {
            C.Native.forward({
                url: 'faq.html'
            });
        },
        goOnlineCustomerCare: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.SETTING_0303
            });
            var hourNow = (new Date()).getHours();
            //hourNow = 10;
            if (hourNow >= 9 && hourNow < 18) {
                C.Native.login({}, function () {
                    C.Native.gotoNative('onlineCustomerCare');
                });
            } else {
                C.Native.tip('现在不是服务时间');
            }
        },

        needIdentity: function () {
            var identity = new Identity({model: {callback: $$.EventListener.onRefresh}});
            $('body').append(identity.el);
        },

        showCustomerCarePhone: function () {
            this.$el.find('.leayer').show();
        },
        callCustomerCarePhone: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.SETTING_0304,
                eventLable: C.TD.Label.SETTING_0304_1
            });
            C.Native.dial('4008580580');
        },
        cancelCustomerCarePhone: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.SETTING_0304,
                eventLable: C.TD.Label.SETTING_0304_2
            });
            this.$el.find('.leayer').hide();
        },
        goSalesNetwork: function () {
            C.Native.gotoNative('salesNetwork');
        },
        goAccountManagement: function () {
            C.Native.login({}, function () {
                C.Native.gotoNative('accountManagement');
            });
        },
        goFeedback: function () {
            C.Native.login({}, function () {
                C.Native.gotoNative('feedback');
            });
        },
        goLogin: function () {
            //埋点
            C.Native.TDOnEvent({
                eventId: C.TD.Event.SETTING_0301,
                eventLable: C.TD.Label.SETTING_0301_1
            });
            C.Native.gotoNative('login');
        },
        doLogout: function () {
            //清空本地数据
            C.Account.logout();
            C.Native.logout(function () {
                $$.EventListener.onRefresh();
            });
        }
    }));

    $(function () {
        var myPage = new Page();

        $$.EventListener.onRefresh = function () {
            C.Native.getUserInfo(function (data) {
                C.Utils.data(C.Constant.DataKey.USER_LOGIN_INFO, data);
                myPage.initialize();
            });
        }
    });
});